<?php
namespace Teknisa\CMP\Modules\Fornecimento\Modules\AutorizacaoFornecimento\Services;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Cmp03900LancamentoAutorizacaoDeFornecimentoService
{
    protected $crudService;
    protected $connection;
    protected $environment;
    protected $newCode;
    protected $fileUploader;
    protected $_fileServerUrl;

    public function __construct($crudService, $connection, $environment, $newCode, $fileUploader, $fileServerUrl)
    {
        $this->crudService       = $crudService;
        $this->connection        = $connection;
        $this->environment       = $environment;
        $this->newCode           = $newCode;
        $this->fileUploader      = $fileUploader;
        $this->_fileServerUrl    = $fileServerUrl;
    }
    
    public function permissoesOperador() {
        $conditions = array(
            ["columnName" => "CDOPERADOR",   "operator" => "=",   "value" => $this->environment->getCdOperador() ],
            ["columnName" => "NRORG",        "operator" => "=",   "value" => $this->environment->getNrOrg()      ]
        );
        $permissoesOperador = $this->crudService->getFilteredDataSet("cmp03900_autgrupop_opergrupop", $conditions);
        return $permissoesOperador;
    }
    
    public function centralCompras() {
        $conditions = array(
            ["columnName" => "CDFILIAL",   "operator" => "=",   "value" => $this->environment->getCdFilial() ],
            ["columnName" => "NRORG",      "operator" => "=",   "value" => $this->environment->getNrOrg()    ]
        );
        $centralCompras = $this->crudService->getFilteredDataSet("centralCompras", $conditions);
        return $centralCompras;
    }
    
    public function parasupri($cdfilial) {
        $conditions = array(
            ["columnName" => "CDFILIAL",   "operator" => "=",   "value" => $cdfilial                       ],
            ["columnName" => "NRORG",      "operator" => "=",   "value" => $this->environment->getNrOrg()  ]
        );
        $parasupri = $this->crudService->getFilteredDataSet("parasupri", $conditions);
        return $parasupri;
    }
    
    public function removePrazoPercentual($row) {
        $query = $this->connection->prepare(
            "DELETE FROM PRAZOPGTAF 
              WHERE CDFILDEST  = :CDFILDEST
                AND CDFILLANC  = :CDFILLANC
                AND NRAUTOFORN = :NRAUTOFORN
                AND NRORG      = :NRORG" );
        $query->execute(array(
            "CDFILDEST"  => $row['CDFILDEST'],
            "CDFILLANC"  => $row['CDFILLANC'],
            "NRAUTOFORN" => $row['NRAUTOFORN'],
            "NRORG"      => $this->environment->getNrOrg()
        ));
    }
    
    public function existeEncargoAF($row) {
        $query = $this->connection->prepare(
            "SELECT 1 FROM ENCARGOAF WHERE
                CDFILDEST   = :CDFILDEST   AND
                CDFILLANC   = :CDFILLANC   AND
                NRAUTOFORN  = :NRAUTOFORN  AND
                DTENTRENCAF = :DTENTRENCAF AND
                CDENCARGO   = :CDENCARGO   AND
                NRORG       = :NRORG" );
        $query->execute(array(
            "CDFILDEST"   => $row['CDFILDEST'],
            "CDFILLANC"   => $row['CDFILLANC'],
            "NRAUTOFORN"  => $row['NRAUTOFORN'],
            "DTENTRENCAF" => $row['DTENTRENCAF'],
            "CDENCARGO"   => $row['CDENCARGO'],
            "NRORG"       => $this->environment->getNrOrg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return true;
        else
            return false;
    }
    
    public function excluirEncargoAFVazio($row) {
        $query = $this->connection->prepare(
            "DELETE FROM ENCARGOAF WHERE
                CDFILDEST   = :CDFILDEST   AND
                CDFILLANC   = :CDFILLANC   AND
                NRAUTOFORN  = :NRAUTOFORN  AND
                DTENTRENCAF = :DTENTRENCAF AND
                NRORG       = :NRORG       AND
                (VRENCARGOAF = 0 OR VRENCARGOAF IS NULL)");
        $query->execute(array(
            "CDFILDEST"   => $row['CDFILDEST'],
            "CDFILLANC"   => $row['CDFILLANC'],
            "NRAUTOFORN"  => $row['NRAUTOFORN'],
            "DTENTRENCAF" => $row['DTENTRENCAF'],
            "NRORG"       => $this->environment->getNrOrg()
        ));
    }
    
    public function editarJustificativa($row) {
        $query = $this->connection->prepare(
            "UPDATE MOVOPAF SET 
                DSJUSTOPERMOV = :DSJUSTOPERMOV,
                DTULTATU      = SYSDATE,
                CDOPERULTATU  = :CDOPERULTATU
            WHERE
                CDFILDESMOV   = :CDFILDESMOV AND
                CDFILLANMOV   = :CDFILLANMOV AND
                NRAUTOMOV     = :NRAUTOMOV   AND
                CDOPERADOR    = :CDOPERADOR  AND
                DTOPERAF      = :DTOPERAF    AND
                NRORG         = :NRORG");
        $query->execute(array(
            "DSJUSTOPERMOV" => $row['DSJUSTOPERMOV'],
            "CDFILDESMOV"   => $row['CDFILDESMOV'],
            "CDFILLANMOV"   => $row['CDFILLANMOV'],
            "NRAUTOMOV"     => $row['NRAUTOMOV'],
            "CDOPERADOR"    => $row['CDOPERADOR'],
            "DTOPERAF"      => $row['DTOPERAF'],
            "CDOPERULTATU"  => $this->environment->getCdOperador(),
            "NRORG"         => $this->environment->getNrOrg()
        ));
    }
    
    public function valorTotalAF($row) {
        $query = $this->connection->prepare(
            "UPDATE
                AUTOFORNE A 
            SET VRTOTALAF = 
                (SELECT SUM(I.QTPROGENTAF * I.VRPREUNIAF - I.VRDESCITMAF) AS SOMA 
                FROM ITEMAUTF I
                    JOIN PRODUTO P ON I.CDPRODUTO = P.CDPRODUTO 
                WHERE
                    I.CDFILDEST       = A.CDFILDEST 
                    AND I.CDFILLANC   = A.CDFILLANC 
                    AND I.NRAUTOFORN  = A.NRAUTOFORN 
                    AND P.CDPRODESTO IS NOT NULL)
            WHERE
                A.CDFILDEST      = :CDFILDEST 
                AND A.CDFILLANC  = :CDFILLANC 
                AND A.NRAUTOFORN = :NRAUTOFORN");
        $query->execute(array(
            "CDFILDEST"  => $row['CDFILDEST'],
            "CDFILLANC"  => $row['CDFILLANC'],
            "NRAUTOFORN" => $row['NRAUTOFORN']
        ));
    }
    
    public function CONSISTE_ORCAMENTO($row) {
        $retorno = "";
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'CONSISTE_ORCAMENTO ');
        $procedure->addParam(new Param('P_CDFILDEST',  Param::PARAM_INPUT,   $row["CDFILDEST"],  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILLANC',  Param::PARAM_INPUT,   $row["CDFILLANC"],  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT,   $row["NRAUTOFORN"], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('retorno',      Param::PARAM_OUTPUT,  $retorno,           Param::PARAM_TYPE_STR));
        $retorno = $procedure->execute();
        return $retorno;
    }
    
    public function CONSISTE_ORCAMENTO_GOP($unidadeDest, $unidadeLanc, $nrdemanda) {
        try{
            $connection = $this->connection;
            $procedure  = new StoredProcedure($connection, 'CONSISTE_ORCAMENTO_GOP');
            $procedure->addParam(new Param('P_CDFILDEST',  Param::PARAM_INPUT,  $unidadeDest,  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILLANC',  Param::PARAM_INPUT,  $unidadeLanc,  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT,  $nrdemanda, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CONSISTE',   Param::PARAM_OUTPUT, NULL, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRORG',      Param::PARAM_INPUT,  $this->environment->getNrOrg(), Param::PARAM_TYPE_STR));
            return $procedure->execute();
        }
        catch(\Exception $e){
            throw $e;
        }
    }
    
    public function retornaParametrosCompras($filial) {
        $conditions = array(
            ["columnName" => "CDFILIAL",   "operator" => "=",   "value" => $filial],
            ["columnName" => "NRORG",      "operator" => "=",   "value" => $this->environment->getNrOrg()]
        );
        $parametrosCompras = $this->crudService->getFilteredDataSet("parametrosCompras", $conditions)->getRows();
        return $parametrosCompras;
    }
    
    public function fornecedor_qualificacao($row) {
        $conditions = array(
            ["columnName" => "DTAUTOFORN",    "operator" => "=",    "value" => $row["DTAUTOFORN"]  ],
            ["columnName" => "CDFORNECED",    "operator" => "=",    "value" => $row["CDFORNECED"]  ],
            ["columnName" => "IDULTIDTVALQ",  "operator" => "=",    "value" => $row["IDULTIDTVALQ"]]
        );
        $qualificado = $this->crudService->getFilteredDataSet("fornecedor_qualificacao", $conditions)->getRows();
        return sizeof($qualificado);
    }
    
    public function fornecedor_filial($row) {
        $conditions = array(
            ["columnName" => "CDFILIAL",     "operator" => "=",    "value" => $row["CDFILDEST"]   ],
            ["columnName" => "CDFORNECED",   "operator" => "=",    "value" => $row["CDFORNECED"]  ],
            ["columnName" => "NRORG",        "operator" => "=",    "value" => $this->environment->getNrOrg() ]
        );
        $filial = $this->crudService->getFilteredDataSet("fornecedor_filial", $conditions)->getRows();
        return sizeof($filial);
    }
    
    public function fornecedor_regiao($row) {
        $conditions = array(
            ["columnName" => "P_CDFILIAL",    "operator" => "=",    "value" => $row["CDFILDEST"]   ],
            ["columnName" => "P_CDFORNECED",  "operator" => "=",    "value" => $row["CDFORNECED"]  ],
            ["columnName" => "NRORG",         "operator" => "=",    "value" => $this->environment->getNrOrg()]
        );
        $regiao = $this->crudService->getFilteredDataSet("fornecedor_regiao", $conditions)->getRows();
        return sizeof($regiao);
    }
    
    public function verificaImposto($row) {
        $conditions = array(
            ["columnName" => "CDFILDEST",   "operator" => "=",    "value" => $row["CDFILDEST"]],
            ["columnName" => "CDEMPRESA",   "operator" => "=",    "value" => $row["CDEMPRESA"]],
            ["columnName" => "NRORG",       "operator" => "=",    "value" => $this->environment->getNrOrg()]
        );
        $imposto = $this->crudService->getFilteredDataSet("cmp03900_verificaImposto", $conditions)->getRows();
        return $imposto;
    }
    
    public function IMPOSTO_ITEMAF($row) {
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'IMPOSTO_ITEMAF');
        $procedure->addParam(new Param('P_EMPRESA',    Param::PARAM_INPUT, $row["CDEMPRESA"],   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INSCESTA',   Param::PARAM_INPUT, $row["CDINSCESTA"],  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_FORNECEDOR', Param::PARAM_INPUT, $row["CDFORNECED"],  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_FILDEST',    Param::PARAM_INPUT, $row["CDFILDEST"],   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_FILLANC',    Param::PARAM_INPUT, $row["CDFILLANC"],   Param::PARAM_TYPE_INT));
        $procedure->addParam(new Param('P_LANCTOAF',   Param::PARAM_INPUT, $row["NRAUTOFORN"],  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_INIVALID',   Param::PARAM_INPUT, $row["DTPROGENTAF"], Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function parcmpsup($row) {
        $conditions = array(
            ["columnName" => "CDFILIAL",   "operator" => "=",    "value" => $row["CDFILDEST"]],
            ["columnName" => "NRORG",      "operator" => "=",    "value" => $this->environment->getNrOrg()   ]
        );
        $parcmpsup = $this->crudService->getFilteredDataSet("parcmpsup", $conditions)->getRows();
        return $parcmpsup;
    }
    
    public function updateCdtpctpagar($row) {
        $query = "UPDATE AUTOFORNE
            SET CDTPCTPAGAR =
              (SELECT PRODUTO.CDTPCTPAGAR
              FROM PRODUTO,
                (SELECT MAX(PRODUTO.CDARVPROD) AS CDARVPROD
                FROM PRODUTO,
                  (SELECT MIN(A.CDARVPROD) AS CDARVPROD
                  FROM
                    (SELECT CDARVPROD
                    FROM ITEMAUTF,
                      PRODUTO P
                    WHERE P.CDPRODUTO       = ITEMAUTF.CDPRODUTO
                    AND ITEMAUTF.CDFILDEST  = :CDFILDEST
                    AND ITEMAUTF.CDFILLANC  = :CDFILLANC
                    AND ITEMAUTF.NRAUTOFORN = :NRAUTOFORN
                    AND ITEMAUTF.NRORG = :NRORG
                    GROUP BY CDARVPROD
                    HAVING MAX(QTPROGENTAF * VRPREUNIAF) =
                      (SELECT MAX(QTPROGENTAF*VRPREUNIAF)
                      FROM ITEMAUTF
                      WHERE ITEMAUTF.CDFILDEST = :CDFILDEST
                      AND ITEMAUTF.CDFILLANC   = :CDFILLANC
                      AND ITEMAUTF.NRAUTOFORN  = :NRAUTOFORN
                      AND ITEMAUTF.NRORG = :NRORG
                      )
                    )A
                  ) ITEMAUTF
                WHERE ITEMAUTF.CDARVPROD LIKE PRODUTO.CDARVPROD
                  || '%'
                AND PRODUTO.CDTPCTPAGAR IS NOT NULL
                AND PRODUTO.NRORG = :NRORG
                ) TIPOCTPAGAR
              WHERE PRODUTO.CDARVPROD  = TIPOCTPAGAR.CDARVPROD
              AND PRODUTO.CDTPCTPAGAR IS NOT NULL
              AND PRODUTO.NRORG = :NRORG
              )
            WHERE AUTOFORNE.CDFILDEST  = :CDFILDEST
            AND AUTOFORNE.CDFILLANC    = :CDFILLANC
            AND AUTOFORNE.NRAUTOFORN   = :NRAUTOFORN
            AND AUTOFORNE.NRORG = :NRORG
            AND AUTOFORNE.CDTPCTPAGAR IS NULL";
        $params = array(
            "CDFILDEST"  => $row["CDFILDEST"],
            "CDFILLANC"  => $row["CDFILLANC"],
            "NRAUTOFORN" => $row["NRAUTOFORN"],
            "NRORG"      => $this->environment->getNrOrg()
        );
        $result = $this->connection->executeUpdate($query, $params);
        return $result;
    }
    
    public function retornaCdtpctpagar($row) {
        $conditions = array(
            ["columnName" => "CDFILDEST",   "operator" => "=",   "value" => $row["CDFILDEST"] ],
            ["columnName" => "CDFILLANC",   "operator" => "=",   "value" => $row["CDFILLANC"] ],
            ["columnName" => "NRAUTOFORN",  "operator" => "=",   "value" => $row["NRAUTOFORN"]],
            ["columnName" => "NRORG",       "operator" => "=",   "value" => $this->environment->getNrOrg()]
        );
        $dataSet = $this->crudService->getFilteredDataSet("detalhesAutoForne", $conditions)->getRows();
        return $dataSet;
    }
    
    public function CUSTO_AF($row) {
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'CUSTO_AF');
        $procedure->addParam(new Param('P_CDFILDEST',   Param::PARAM_INPUT, $row["CDFILDEST"],   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILLANC',   Param::PARAM_INPUT, $row["CDFILLANC"],   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRAUTOFORN',  Param::PARAM_INPUT, $row["NRAUTOFORN"],  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQAPURAF', Param::PARAM_INPUT, $row["NRSEQAPURAF"], Param::PARAM_TYPE_STR));
        $procedure->execute();
    }
    
    public function retornaProdutos($row) {
        $conditions = array(
            ["columnName" => "CDFILLANC",   "operator" => "=",   "value" => $row["CDFILLANC"] ],
            ["columnName" => "CDFILDEST",   "operator" => "=",   "value" => $row["CDFILDEST"] ],
            ["columnName" => "NRAUTOFORN",  "operator" => "=",   "value" => $row["NRAUTOFORN"]],
            ["columnName" => "NRORG",       "operator" => "=",   "value" => $this->environment->getNrOrg()]
        );
        $dataSet = $this->crudService->getFilteredDataSet("af_produtos", $conditions)->getRows();
        return $dataSet;
    }
    
    public function inserirJustificativa($row) 
    { 
        $nrorg      = $this->environment->getNrOrgTrab();
        $cdoperador = $this->environment->getCdOperador();
        $query = $this->connection->prepare(
            "INSERT INTO MOVOPAF (
                CDFILDESMOV, CDFILLANMOV, NRAUTOMOV, DTPROGENTMOV, IDOPERAMOVAF, DSALTERAF, DSJUSTOPERMOV, CDPRODMOV, CDMARCMOV,
                IDATIVO, NRORG, DTULTATU, DTINCLUSAO, DTOPERAF, NRORGULTATU, NRORGINCLUSAO, CDOPERADOR, CDOPERULTATU, CDOPERINCLUSAO
            ) VALUES (
                :CDFILDESMOV, :CDFILLANMOV, :NRAUTOMOV, :DTPROGENTMOV, :IDOPERAMOVAF, :DSALTERAF, :DSJUSTOPERMOV, :CDPRODMOV, :CDMARCMOV,
                :IDATIVO, :NRORG, SYSDATE, SYSDATE, SYSDATE, :NRORGULTATU, :NRORGINCLUSAO, :CDOPERADOR, :CDOPERULTATU, :CDOPERINCLUSAO
            )");
        $query->execute(array(
            "CDFILDESMOV"    => $row["CDFILDESMOV"],
            "CDFILLANMOV"    => $row["CDFILLANMOV"],
            "NRAUTOMOV"      => $row["NRAUTOMOV"],
            "DTPROGENTMOV"   => $row["DTPROGENTMOV"],
            "IDOPERAMOVAF"   => $row["IDOPERAMOVAF"],
            "DSALTERAF"      => $row["DSALTERAF"],
            "DSJUSTOPERMOV"  => $row["DSJUSTOPERMOV"],
            "CDPRODMOV"      => empty($row["CDPRODMOV"]) ? null : $row["CDPRODMOV"],
            "CDMARCMOV"      => empty($row["CDMARCMOV"]) ? null : $row["CDMARCMOV"],
            "IDATIVO"        => "S",
            "NRORG"          => $nrorg,
            "NRORGULTATU"    => $nrorg,
            "NRORGINCLUSAO"  => $nrorg,
            "CDOPERADOR"     => $cdoperador,
            "CDOPERULTATU"   => $cdoperador,
            "CDOPERINCLUSAO" => $cdoperador
        ));
    }
    
    public function excluiProdutosDiferentes($row) {
        $query = $this->connection->prepare(
            "DELETE FROM ITEMAUTF 
             WHERE CDFILDEST   = :CDFILDEST
               AND CDFILLANC   = :CDFILLANC
               AND NRAUTOFORN  = :NRAUTOFORN
               AND CDPRODUTO   = :CDPRODUTO
               AND CDMARCA     = :CDMARCA
               AND DTPROGENTAF = :DTPROGENTAF
               AND NRORG       = :NRORG" );
        $query->execute(array(
            "CDFILDEST"   => $row["CDFILDEST"],
            "CDFILLANC"   => $row["CDFILLANC"],
            "NRAUTOFORN"  => $row["NRAUTOFORN"],
            "CDPRODUTO"   => $row["CDPRODUTO"],
            "CDMARCA"     => $row["CDMARCA"],
            "DTPROGENTAF" => $row["DTPROGENTAF"],
            "NRORG"       => $this->environment->getNrOrg()
        ));
    }
    
    public function parasupri_filial_validacao($cdfilial) {
        $query = $this->connection->prepare(
            "SELECT PAR.NRORG,
              NVL(FIL.CDFILCENTCMP, FIL.CDFILIAL) AS CDFILIAL
            FROM PARASUPRI PAR,
              FILIAL FIL
            WHERE FIL.CDFILIAL = :CDFILIAL
            AND PAR.NRORG      = :NRORG
            AND PAR.CDFILIAL   = NVL(FIL.CDFILCENTCMP, FIL.CDFILIAL)");
        $query->execute(array(
            "CDFILIAL" => $cdfilial,
            "NRORG"    => $this->environment->getNrOrg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return true;
        else
            return false;
    }
    
    public function parcmpsup_validacao($cdfilial) {
        $query = $this->connection->prepare(
            "SELECT IDTIPEMITGER FROM PARCMPSUP WHERE CDFILIAL = :CDFILIAL AND NRORG = :NRORG");
        $query->execute(array(
            "CDFILIAL" => $cdfilial,
            "NRORG"    => $this->environment->getNrOrg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return $existe[0]["IDTIPEMITGER"];
        else
            return false;
    }
    
    public function paramgeral_validacao() {
        $query = $this->connection->prepare(
            "SELECT IDUTILDTPROC FROM PARAMGERAL WHERE NRORG = :NRORG");
        $query->execute(array(
            "NRORG"=> $this->environment->getNrOrg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return $existe[0]["IDUTILDTPROC"];
        else
            return false;
    }
    
    public function paramfilial_validacao($cdfilial) {
        $query = $this->connection->prepare(
            "SELECT DTPROCESSA FROM PARAMFILIAL WHERE CDFILIAL = :CDFILIAL AND NRORG = :NRORG");
        $query->execute(array(
            "CDFILIAL" => $cdfilial,
            "NRORG"    => $this->environment->getNrOrg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return $existe[0]["DTPROCESSA"];
        else
            return false;
    }
    
    public function senhaOperador($cdoperador) {
        $query = $this->connection->prepare(
            "SELECT CDSENHAOPERWEB FROM OPERADOR WHERE CDOPERADOR = :CDCOMPRADOR");
        $query->execute(array(
            "CDCOMPRADOR" => $cdoperador
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return $existe[0]["CDSENHAOPERWEB"];
        else
            return false;
    }
    
    public function fornecedor($row) {
        $conditions = array(
            ["columnName" => "CDFORNECED",   "operator" => "=",   "value" => $row["CDFORNECED"]],
            ["columnName" => "NRORG",        "operator" => "=",   "value" => $this->environment->getNrOrg()]
        );
        $dataSet = $this->crudService->getFilteredDataSet("fornecedor", $conditions)->getRows()[0];
        return $dataSet;
    }
    
    public function retornTipoCobranca($cdtipcob) {
        $query = $this->connection->prepare(
            "SELECT NMTIPOCOBR FROM TIPOCOBR WHERE CDTIPCOB= :CDTIPCOB");
        $query->execute(array(
            "CDTIPCOB" => $cdtipcob
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return $existe[0]["NMTIPOCOBR"];
        else
            return "";
    }
    
    public function novoCodigo($cdfildest, $cdfillanc) {
        return $this->newCode->getCodeByTableName('AUTOFORNE', $this->environment->getNrOrg());
    }
    
    public function excluiTodosProdutos($row) {
        $query = $this->connection->prepare(
            "DELETE FROM ITEMAUTF WHERE
            CDFILDEST  = :CDFILDEST  AND
            CDFILLANC  = :CDFILLANC  AND
            NRAUTOFORN = :NRAUTOFORN AND
            NRORG      = :NRORG" );
        $query->execute(array(
            "CDFILDEST"  => $row["CDFILDEST"],
            "CDFILLANC"  => $row["CDFILLANC"],
            "NRAUTOFORN" => $row["NRAUTOFORN"],
            "NRORG"      => $this->environment->getNrOrg()
        ));
    }
    
    public function excluirAF($row) 
    {
        $query = $this->connection->prepare(
            "DELETE FROM AUTOFORNE WHERE
            CDFILDEST  = :CDFILDEST  AND
            CDFILLANC  = :CDFILLANC  AND
            NRAUTOFORN = :NRAUTOFORN AND
            NRORG      = :NRORG" );
        $query->execute(array(
            "CDFILDEST"  => $row["CDFILDEST"],
            "CDFILLANC"  => $row["CDFILLANC"],
            "NRAUTOFORN" => $row["NRAUTOFORN"],
            "NRORG"      => $this->environment->getNrOrg()
        ));
    }
    
    public function existeInconsistencias($row) {
        $conditions = array(
            ["columnName" => "CDFILLANC",    "operator" => "=",    "value" => $row["CDFILLANC"]  ],
            ["columnName" => "CDFILDEST",    "operator" => "=",    "value" => $row["CDFILDEST"]  ],
            ["columnName" => "CDFILCENT",    "operator" => "=",    "value" => $row["CDFILCENT"]  ],
            ["columnName" => "NRAUTOFORN",   "operator" => "=",    "value" => $row["NRAUTOFORN"] ],
            ["columnName" => "NRORG",        "operator" => "=",    "value" => $this->environment->getNrOrg()]
        );   
        
        $inconsistencias = $this->crudService->getFilteredDataSet("inconsistencia", $conditions)->getRows();
        
        return $inconsistencias;
    }
    
    public function validaProdutoComprador($row) {
        $query = $this->connection->prepare(
            "SELECT
              COUNT(*) as CONTA
            FROM
              PRODCOMP,
              PRODUTO
            WHERE
              (PRODUTO.CDPRODUTO = PRODCOMP.CDPRODUTO) AND
              (CDOPERADOR = :P_CDOPERADOR)  AND
              (:P_CDARVPROD LIKE PRODUTO.CDARVPROD || '%')");
        $query->execute(array(
            "P_CDARVPROD"  => $row['CDARVPROD'],
            "P_CDOPERADOR" => $row['OPERADOR']
        ));
        $existe = $query->fetchAll();
        if($existe[0]["CONTA"] > 0)
            return true;
        else
            return false;
    }
    
    public function validaProdutoNaoCompradoPelaFilial($row) {
        $query = $this->connection->prepare(
            "SELECT COUNT(*)  AS CONTA
            FROM PRODNCMP, PRODUTO
            WHERE
               PRODNCMP.CDPRODUTO = PRODUTO.CDPRODUTO AND
               PRODNCMP.CDFILIAL = :P_CDFILDEST AND
               :P_CDARVPROD LIKE PRODUTO.CDARVPROD||'%' AND
               PRODUTO.CDARVPROD > (SELECT NVL(MAX(PR.CDARVPROD), '0')
                                    FROM PRODCMPFILI, PRODUTO PR
                                    WHERE PRODCMPFILI.CDPRODUTO = PR.CDPRODUTO AND
                                        :P_CDARVPROD LIKE PR.CDARVPROD||'%' AND
                                        PRODCMPFILI.CDFILIAL = :P_CDFILDEST)");
        $query->execute(array(
            "P_CDARVPROD" => $row['CDARVPROD'],
            "P_CDFILDEST" => $row['CDFILDEST']
        ));
        $existe = $query->fetchAll();
        if($existe[0]["CONTA"] > 0)
            return false;
        else
            return true;
    }
    
    public function validaProdutoPorFornecedor($row) {
        $query = $this->connection->prepare(
            "SELECT COUNT (*) CONTA
               FROM (SELECT 1
                       FROM PRODFORN INNER JOIN PRODUTO ON PRODFORN.CDPRODUTO = PRODUTO.CDPRODUTO
                                                       AND PRODFORN.NRORG = PRODUTO.NRORG        
                      WHERE :P_CDARVPROD LIKE PRODUTO.CDARVPROD||'%'
                        AND PRODFORN.CDFORNECED = :P_CDFORNECED
                        AND PRODFORN.NRORG = :NRORG
                      UNION ALL
                     SELECT 1
                       FROM PRODFORN INNER JOIN PRODUTO ON PRODFORN.CDPRODUTO = PRODUTO.CDPRODUTO
                                                       AND PRODFORN.NRORG = PRODUTO.NRORG    
                      WHERE PRODFORN.CDFORNECED = :P_CDFORNECED
                        AND PRODFORN.NRORG = :NRORG
                        AND (SELECT DISTINCT CDARVPROD
                               FROM PRODUTO INNER JOIN RELACPRODOL ON RELACPRODOL.CDPRARVORIG = PRODUTO.CDPRODUTO
                                                                  AND RELACPRODOL.NRORG = PRODUTO.NRORG 
                              WHERE RELACPRODOL.CDPRODARVOL = :P_CDPRODUTO
                                AND RELACPRODOL.NRORG = :NRORG) LIKE PRODUTO.CDARVPROD||'%')");
        $query->execute(array(
            "P_CDPRODUTO"  => $row['CDPRODUTO'],
            "P_CDARVPROD"  => $row['CDARVPROD'],
            "P_CDFORNECED" => $row['CDFORNECED'],
            "NRORG"        => $this->environment->getNrorg()
        ));
        $existe = $query->fetchAll();
        if($existe[0]["CONTA"] == 0)
            return false;
        else
            return true;
    }
    
    public function getVerifProdCompFilial($row){
        $query = "SELECT IDVERPRODCMPFIL FROM PARASUPRI WHERE CDFILIAL = :P_CDFILIAL AND NRORG = :P_NRORG";
        $std = $this->connection->prepare($query);
        $std->execute([
            "P_CDFILIAL"  => $row['CDFILCENTCMP'],
            "P_NRORG"     => $this->environment->getNrorg()
        ]);     
        return $std->fetchAll();
    }
    
    public function validaProdutoCompradoPelaFilial($row) {
        $idverproccmpfil = self::getVerifProdCompFilial($row);
        if($idverproccmpfil[0]['IDVERPRODCMPFIL'] == 'S'){
            $query = $this->connection->prepare(
                "SELECT COUNT(1) AS CONTA
                  FROM PRODCMPFILI, PRODUTO, PRODUTO PRCMPFILI
                 WHERE PRODCMPFILI.CDFILIAL  = :P_CDFILDEST
                   AND PRODCMPFILI.CDPRODUTO = PRCMPFILI.CDPRODUTO
                   AND PRODUTO.CDPRODUTO     = :P_CDPRODUTO
                   AND PRODUTO.CDARVPROD LIKE PRCMPFILI.CDARVPROD||'%'
                   AND PRCMPFILI.CDARVPROD > (SELECT NVL(MAX(PR.CDARVPROD), '0')
                                                FROM PRODNCMP, PRODUTO PR
                                               WHERE PRODNCMP.CDPRODUTO = PR.CDPRODUTO
                                                 AND PRODUTO.CDARVPROD LIKE PR.CDARVPROD||'%'
                                                 AND PRODNCMP.CDFILIAL = :P_CDFILDEST)");
            $query->execute(array(
                "P_CDPRODUTO" => $row['CDPRODUTO'],
                "P_CDFILDEST" => $row['CDFILDEST']
            ));
            $existe = $query->fetchAll();
            
            if($row['CDFILLANC'] == $row['CDFILCENTCMP']){
                if($existe[0]["CONTA"] == 0)
                    return true;
                else
                    return false;    
            } else if($row['CDFILDEST'] == $row['CDFILLANC']){
                if($existe[0]["CONTA"] == 0)
                    return false;
                else
                    return true;  
            }
        } else {
            return true;
        }
    }
    
    public function produtoAtivo($row) {
        $query = $this->connection->prepare(
            "SELECT IDPRODATIVPR FROM PRODUTO WHERE CDPRODUTO = :P_CDPRODUTO");
        $query->execute(array(
            "P_CDPRODUTO" => $row['CDPRODUTO']
        ));
        $produto = $query->fetchAll();
        if($produto[0]["IDPRODATIVPR"] == 'S')
            return true;
        else
            return false;
    }
    
    public function produtoAtivoFilial($row) {
        $query = $this->connection->prepare(
            "SELECT IDPRODATIV FROM PRODFILI WHERE CDPRODUTO = :P_CDPRODUTO AND CDFILIAL = :P_CDFILIAL");
        $query->execute(array(
            "P_CDPRODUTO" => $row['CDPRODUTO'],
            "P_CDFILIAL"  => $row['CDFILDEST']
        ));
        $produto = $query->fetchAll();
        if(!isset($produto[0]) || $produto[0]["IDPRODATIV"] == 'A')
            return true;
        else
            return false;
    }
    
    public function verificaProdutodDuplicado($row)
    {
        $query = $this->connection->prepare(
            "SELECT CDPRODUTO
               FROM ITEMAUTF
              WHERE NRAUTOFORN  = :P_NRAUTOFORN
                AND CDFILDEST   = :P_CDFILDEST
                AND CDFILLANC   = :P_CDFILLANC
                AND CDPRODUTO   = :P_CDPRODUTO
                AND CDMARCA     = :P_CDMARCA
                AND NRORG       = :NRORG");
        $query->execute(array(
            "P_CDFILDEST"   => $row['CDFILDEST'],
            "P_CDFILLANC"   => $row['CDFILLANC'],
            "P_NRAUTOFORN"  => $row['NRAUTOFORN'],
            "P_CDMARCA"     => $row['CDMARCA'],
            "P_CDPRODUTO"   => $row['CDPRODUTO'],
            "NRORG"       => $this->environment->getNrOrg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return true;
        else
            return false;
    }
    
    public function validaMultiplasDatasEntrega($row) {
        $query = $this->connection->prepare(
            "SELECT *
               FROM ITEMAUTF
              WHERE NRAUTOFORN  = :P_NRAUTOFORN
                AND CDFILDEST   = :P_CDFILDEST
                AND CDFILLANC   = :P_CDFILLANC
                AND DTPROGENTAF <> :P_DTPROGENTAF
                AND (CDFILDEST      <> :P_CDFILDEST
                     OR CDFILLANC   <> :P_CDFILLANC
                     OR NRAUTOFORN  <> :P_NRAUTOFORN
                     OR CDMARCA     <> :P_CDMARCA
                     OR CDPRODUTO   <> :P_CDPRODUTO
                     OR DTPROGENTAF <> :P_DTPROGBKP
                     OR NRORG       <> :P_NRORG)");
        $query->execute(array(
            "P_CDFILDEST"   => $row['CDFILDEST'],
            "P_CDFILLANC"   => $row['CDFILLANC'],
            "P_NRAUTOFORN"  => $row['NRAUTOFORN'],
            "P_CDMARCA"     => isset($row['CDMARCA'])   ? $row['CDMARCA']   : " ",
            "P_CDPRODUTO"   => isset($row['CDPRODUTO']) ? $row['CDPRODUTO'] : " ",
            "P_DTPROGENTAF" => $row['DTPROGENTAF'],
            "P_DTPROGBKP"   => $row['DTPROGBKP'],
            "P_NRORG"       => $this->environment->getNrorg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            if(isset($row["CDPRODUTO"]) && $row["CDPRODUTO"] == $existe[0]["CDPRODUTO"] && isset($row["CDMARCA"]) && $row["CDMARCA"] == $existe[0]["CDMARCA"])
                return true;
            else
                return false;
        else
            return true;
    }
    
    public function novoCodigoMensagem($row) {
        $query = $this->connection->prepare(
            "SELECT COUNT(*) AS NOVO_CODIGO
            FROM MENSAUTF
            WHERE CDFILLANC  = :CDFILLANC
              AND CDFILDEST  = :CDFILDEST
              AND NRAUTOFORN = :NRAUTOFORN");
        $query->execute(array(
            "CDFILDEST"  => $row['CDFILDEST'],
            "CDFILLANC"  => $row['CDFILLANC'],
            "NRAUTOFORN" => $row['NRAUTOFORN']
        ));
        return $query->fetchAll()[0]["NOVO_CODIGO"];
    }
    
    public function retornaMensagens($row) {
        $query = $this->connection->prepare(
            "SELECT *
            FROM MENSAUTF
            WHERE CDFILDEST = :CDFILDEST
              AND CDFILLANC = :CDFILLANC
              AND NRAUTOFORN = :NRAUTOFORN
              AND NRMENSAUTFOR > :NRMENSAUTFOR
            ORDER BY NRMENSAUTFOR ASC");
        $query->execute(array(
            "CDFILDEST"    => $row['CDFILDEST'],
            "CDFILLANC"    => $row['CDFILLANC'],
            "NRAUTOFORN"   => $row['NRAUTOFORN'],
            "NRMENSAUTFOR" => $row['NRMENSAUTFOR']
        ));
        return $query->fetchAll();
    }
    
    public function atualizaMensagem($row) {
        $query = $this->connection->prepare(
            "UPDATE MENSAUTF
            SET NRMENSAUTFOR   = :P_NOVOCODIGO
            WHERE CDFILDEST    = :P_CDFILDEST
              AND CDFILLANC    = :P_CDFILLANC
              AND NRAUTOFORN   = :P_NRAUTOFORN
              AND NRMENSAUTFOR = :P_NRMENSAUTFOR
              AND NRORG        = :P_NRORG");
        $query->execute(array(
            "P_NOVOCODIGO"   => str_pad($row['NRMENSAUTFOR'] - 1, 2, '0', STR_PAD_LEFT),
            "P_CDFILDEST"    => $row['CDFILDEST'],
            "P_CDFILLANC"    => $row['CDFILLANC'],
            "P_NRAUTOFORN"   => $row['NRAUTOFORN'],
            "P_NRMENSAUTFOR" => $row['NRMENSAUTFOR'],
            "P_NRORG"        => $this->environment->getNrorg()
        ));
    }

    public function getParamCotacao($centralCompras) {
        $query = "SELECT IDCARPRECLAF, IDBLOQFORNCOTAF, CDOPERADOR, IDUTINDICECOL FROM PARASUPRI WHERE CDFILIAL = :P_CDFILIAL";
        $std = $this->connection->prepare($query);
        $std->execute( [ "P_CDFILIAL" => $centralCompras ] );     
        return $std->fetchAll();
    }
    
    public function getCotacao($params) 
    {
        $query = "SELECT CDFILIAL, VRPRECUNIITM, CDMARCA, NMMARCA, VRINDICEITMCOL FROM ( SELECT PRODFILCOT.CDFILIAL, PRODFILCOT.CDMARCA, MARCA.NMMARCA, PRODFILCOT.VRPRECUNIITM, PRODFILCOT.VRINDICEITMCOL, DECODE(PRODPREFMED.CDPRODPREF, NULL, '0', '1') || DECODE(PPMF.CDTIPPART, NULL, '0', PPMF.CDTIPPART) || DECODE(PPF.CDTIPPART, NULL, '0', DECODE(PPF.CDTIPPART, '4', DECODE(PPF.CDGRUPPROD || PPF.CDSUBGRPROD, NULL, '4', 'A'), PPF.CDTIPPART)) || DECODE(PPM.CDTIPPART, NULL, '0', PPM.CDTIPPART) || DECODE(PRODFILCOT.IDITMLISPREC, 'S', '1', '2') ||'00000' AS IDMOTIVPRESC FROM ( SELECT FILIAL.CDFILIAL, PRODUTO.CDPRODESTO, PRODUTO.CDPRODUTO, PRODUTO.VRFATOCONV, ITEMCOLE.CDMARCA, ITEMCOLE.CDFORNECED, ITEMCOLE.VRPRECUNIITM, ITEMCOLE.VRINDICEITMCOL, ITEMCOLE.VRPRECECOITM, ITEMCOLE.VRPRECOITMPI, ITEMCOLE.IDITMLISPREC, ITEMCOLE.NRORG FROM ITEMCOLE INNER JOIN COLETAPR ON ITEMCOLE.CDFILIAL = COLETAPR.CDFILIAL AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO AND ITEMCOLE.NRORG = COLETAPR.NRORG INNER JOIN FILIAL ON ITEMCOLE.CDREGIAO = FILIAL.CDREGIAO AND ITEMCOLE.NRORG    = FILIAL.NRORG INNER JOIN PRODUTO ON ITEMCOLE.CDPRODUTO = PRODUTO.CDPRODUTO AND ITEMCOLE.NRORG     = PRODUTO.NRORG WHERE ITEMCOLE.CDFILIAL   = :P_CDCENTCMP AND ITEMCOLE.CDFORNECED = :P_CDFORNECED AND :P_DTPROGENTAF BETWEEN ITEMCOLE.DTINIVALITM AND ITEMCOLE.DTFINVALITM AND FILIAL.CDFILIAL     = :P_CDFILDEST AND PRODUTO.CDPRODUTO   = :P_CDPRODUTO AND NVL(CDTPINDICECOL, 'XXX') = NVL(:P_CDTPINDICECOL, 'XXX') AND NVL(IDPERVALORCOL, 'XXX') = NVL(:P_IDPERVALORCOL, 'XXX') AND NVL(CDINDICECOL, 'XXX') = NVL(:P_CDINDICECOL, 'XXX') AND NVL(DTREFINDCOL, '01/01/1900') = NVL(:P_DTREFINDCOL, '01/01/1900') AND ITEMCOLE.VRPRECUNIITM > 0 ) PRODFILCOT INNER JOIN MARCA ON PRODFILCOT.CDMARCA = MARCA.CDMARCA AND PRODFILCOT.NRORG = MARCA.NRORG LEFT JOIN PRODPREFMED ON PRODFILCOT.CDFILIAL   = PRODPREFMED.CDFILIAL AND PRODFILCOT.CDPRODESTO = PRODPREFMED.CDPRODUTO AND PRODFILCOT.CDPRODUTO  = PRODPREFMED.CDPRODPREF LEFT JOIN PARTFILI PPM ON PRODFILCOT.CDFILIAL   = PPM.CDFILIAL AND PRODFILCOT.CDPRODUTO  = PPM.CDPRODUTO AND PRODFILCOT.CDMARCA    = PPM.CDMARCA LEFT JOIN PARTFILI PPF ON PRODFILCOT.CDFILIAL   = PPF.CDFILIAL AND PRODFILCOT.CDPRODUTO  = PPF.CDPRODUTO AND PRODFILCOT.CDFORNECED = PPF.CDFORNECED LEFT JOIN PARTFILI PPMF ON PRODFILCOT.CDFILIAL   = PPMF.CDFILIAL AND PRODFILCOT.CDPRODUTO  = PPMF.CDPRODUTO AND PRODFILCOT.CDMARCA    = PPMF.CDMARCA AND PRODFILCOT.CDFORNECED = PPMF.CDFORNECED, PARASUPRI WHERE PARASUPRI.CDFILIAL = :P_CDCENTCMP ORDER BY /* Estabelecendo prioridades - O primeiro registro retornado será o escolhido */ DECODE(PRODPREFMED.CDPRODPREF, NULL,                               -1, -10), DECODE(PPMF.CDTIPPART, '7',                                        -9, '8', -8, '9', 1, 0), DECODE(PPF.CDTIPPART, '4',                                         -9, '5', -8, '6', 1, 0), DECODE(PPM.CDTIPPART, '1',                                         -9, '2', -8, '3', 1, 0), DECODE(PPF.NRCOLEPRECO, NULL, DECODE(PRODFILCOT.IDITMLISPREC, 'S', -6, -5), -7), /*ALTERACAO SAPORE 31/01/2020*/ DECODE(PPF.CDTIPPART, '4', DECODE (PARASUPRI.IDTIPOAPUR, NULL, PRODFILCOT.VRPRECUNIITM, '1', PRODFILCOT.VRPRECECOITM, PRODFILCOT.VRPRECOITMPI) / PRODFILCOT.VRFATOCONV, /* COLOCANDO O PRECO NA MESMA UNIDADE PARA FAZER A ORDENACAO... */ DECODE(PRODFILCOT.IDITMLISPREC, 'S',                                                                                -6, -5)), DECODE (PARASUPRI.IDTIPOAPUR, NULL, PRODFILCOT.VRPRECUNIITM, '1', PRODFILCOT.VRPRECECOITM, PRODFILCOT.VRPRECOITMPI) / PRODFILCOT.VRFATOCONV ) /* COLOCANDO O PRECO NA MESMA UNIDADE PARA FAZER A ORDENACAO... */ WHERE ROWNUM = 1";
        $std = $this->connection->prepare($query);
        $std->execute([
            "P_CDCENTCMP" => $params['CDFILCENTCMP'] ,
            "P_CDFORNECED" => $params['CDFORNECED'],
            "P_CDFILDEST" => $params['CDFILDEST'],
            "P_CDPRODUTO" => $params['CDPRODUTO'],
            "P_DTPROGENTAF" => $params['DTPROGENTAF'],
            
            "P_CDTPINDICECOL" => $params['CDTPINDICECOL'],
            "P_IDPERVALORCOL" => $params['IDPERVALORCOL'],
            "P_CDINDICECOL" => $params['CDINDICECOL'],
            "P_DTREFINDCOL" => $params['DTREFINDCOL']
    
        ]);     
        return $std->fetchAll();
    }
    
    public function getParamUtilProdEstoque($row){
        $query = "SELECT IDUTLPROCMPAF FROM PARASUPRI WHERE CDFILIAL = :P_CDFILIAL AND NRORG = :P_NRORG";
        $std = $this->connection->prepare($query);
        $std->execute([
            "P_CDFILIAL"  => $row['CDFILCENTCMP'],
            "P_NRORG"     => $this->environment->getNrorg()
        ]);     
        return $std->fetchAll();
    }
    
    public function validaProdutoEstoque($row){
        $query = "SELECT CDPRODESTO FROM PRODUTO WHERE (CDPRODUTO = :P_CDPRODUTO) AND CDPRODESTO IS NOT NULL AND CDPRODESTO = CDPRODUTO AND NRORG = :P_NRORG";
        $std = $this->connection->prepare($query);
        $std->execute([
            "P_CDPRODUTO" => $row['CDPRODUTO'],
            "P_NRORG"     => $this->environment->getNrorg()
        ]);     
        return $std->fetchAll();
    }
    
    public function getFormPgtoFornecedor($params) {
        $query = "SELECT NRDIASPGTOFO, VRPERCPGTOFO FROM PRAZOPGTFORN WHERE CDFORNECED = :P_CDFORNECED";
        $std = $this->connection->prepare($query);
        $std->execute([
            "P_CDFORNECED" => $params['CDFORNECED']
        ]);     
        return $std->fetchAll();
    }
    
    public function getOperadorRelacionado($params) {
        $query = "SELECT COMPROPER.CDOPERADOR FROM COMPROPER WHERE COMPROPER.CDOPERADOR = :P_CDOPERADOR AND COMPROPER.CDCOMPRADOR = :P_COMPRADORAF AND COMPROPER.NRORG = :P_NRORG UNION ALL SELECT CDOPERADOR FROM COMPRADOR WHERE CDOPERADOR = :P_CDOPERADOR AND CDOPERADOR = :P_COMPRADORAF AND NRORG = :P_NRORG";
        $std = $this->connection->prepare($query);
        $std->execute([
            "P_CDOPERADOR" => self::operadorLogado(),
            "P_COMPRADORAF" => $params['OPERADOR'],
            "P_NRORG" => $this->environment->getNrorg()
        ]);     
        return $std->fetchAll();
    }
    
    public function getCountProdutos($params)
    {
        $query = "SELECT
                        COUNT(*) QTDE
                    FROM
                        ITEMAUTF
                    WHERE
                        ITEMAUTF.NRORG = :NRORG
                        AND ITEMAUTF.CDFILDEST = :CDFILDEST
                        AND ITEMAUTF.CDFILLANC = :CDFILLANC
                        AND ITEMAUTF.NRAUTOFORN = :NRAUTOFORN";
        $std = $this->connection->prepare($query);
        $std->execute(
            [
                "CDFILDEST"  => $params['CDFILDEST'],
                "CDFILLANC"  => $params['CDFILLANC'],
                "NRAUTOFORN" => $params['NRAUTOFORN'],
                "NRORG"      => $this->environment->getNrorg(),
            ]
        );
        
        return $std->fetch();
    }
    
    public function getCountProdutosBaixados($params)
    {
        $query = "SELECT
                        COUNT(*) QTDE
                    FROM
                        ITEMAUTF
                    WHERE
                        ITEMAUTF.NRORG = :NRORG
                        AND ITEMAUTF.CDFILDEST = :CDFILDEST
                        AND ITEMAUTF.CDFILLANC = :CDFILLANC
                        AND ITEMAUTF.NRAUTOFORN = :NRAUTOFORN
                        AND NVL(ITEMAUTF.IDBAIXITMAF, '1') > '1'";
        $std = $this->connection->prepare($query);
        $std->execute(
            [
                "CDFILDEST"  => $params['CDFILDEST'],
                "CDFILLANC"  => $params['CDFILLANC'],
                "NRAUTOFORN" => $params['NRAUTOFORN'],
                "NRORG"      => $this->environment->getNrorg(),
            ]
        );
        
        return $std->fetch();
    }
    
    public function updateBaixaAf($params){
        $query = "UPDATE AUTOFORNE SET IDBAIXAAF = :IDBAIXAAF WHERE CDFILDEST = :OLD_CDFILDEST AND CDFILLANC = :OLD_CDFILLANC AND NRAUTOFORN = :OLD_NRAUTOFORN";
        $std = $this->connection->prepare($query);
        $std->execute([
            "IDBAIXAAF"      => $params['IDBAIXAAF'],
            "OLD_CDFILDEST"  => $params['CDFILDEST'],
            "OLD_CDFILLANC"  => $params['CDFILLANC'],
            "OLD_NRAUTOFORN" => $params['NRAUTOFORN'] 
        ]);
    }
    
    public function salvaJustLancAf($params){
        $query = "UPDATE AUTOFORNE SET DSMOTVAFALCADA = :DSMOTVAFALCADA WHERE CDFILDEST = :CDFILDEST AND CDFILLANC = :CDFILLANC AND NRAUTOFORN = :NRAUTOFORN";
        $std = $this->connection->prepare($query);
        $std->execute([
            "CDFILDEST"      => $params['CDFILDEST'],
            "CDFILLANC"      => $params['CDFILLANC'],
            "NRAUTOFORN"     => $params['NRAUTOFORN'],
            "DSMOTVAFALCADA" => $params['DSMOTVAFALCADA']
        ]);
    }
    
    public function verificaPrecoCotacaoAF($row) {
        $query = $this->connection->prepare(
            "SELECT
               ITEMAUTF.IDTIPOLANITM,
               ITEMAUTF.NRCOTPREITAF,
               ITEMAUTF.NRLISTAITAF,
               ITEMAUTF.IDMOTPRESCAF
            FROM
               ITEMAUTF,
               PRODUTO,
               MARCA A,
               MARCA B,
               OPERADOR OP
            WHERE
               (ITEMAUTF.CDFILDEST  = :P_CDFILDEST    ) AND
               (ITEMAUTF.CDFILLANC  = :P_CDFILLANC    ) AND
               (ITEMAUTF.NRAUTOFORN = :P_NRAUTOFORN   ) AND
               (ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO) AND
               (ITEMAUTF.CDMARCA    = A.CDMARCA(+)     ) AND
               (ITEMAUTF.CDSEGMARCA = B.CDMARCA(+)     ) AND
               (ITEMAUTF.CDOPERBAIXA = OP.CDOPERADOR(+))
            ORDER BY
               ITEMAUTF.DTPROGENTAF");
        $query->execute(array(
            "P_CDFILDEST" => $row['CDFILDEST'],
            "P_CDFILLANC" => $row['CDFILLANC'],
            "P_NRAUTOFORN" => $row['NRAUTOFORN'],
        ));
        
        return $query->fetch();
    }
    
    public function utilizaWorkflow($cdfildest) {
        
        $query = "SELECT IDUTLWORKFLOW FROM PARASUPRI WHERE CDFILIAL = (SELECT NVL(CDFILCENTCMP, CDFILIAL) CDFILCENTCMP FROM FILIAL WHERE CDFILIAL = :P_CDFILIAL)";
        $params = array(
            "P_CDFILIAL" => $cdfildest
        );
            
        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        $utilizaWorkflow = $stmt->fetchAll();
        
        return is_array($utilizaWorkflow) && count($utilizaWorkflow) ? $utilizaWorkflow[0]['IDUTLWORKFLOW'] : 'N';
        
    }
    
    public function operadorLogado() {
        return $this->environment->getCdOperador();
    }
    
    public function retornaTipoCobranca($cdTipCob) {
        $query = $this->connection->prepare(
            "SELECT NMTIPOCOBR
               FROM TIPOCOBR
              WHERE CDTIPCOB = :P_CDTIPCOB
                AND NRORG = :NRORG
              ORDER BY CDTIPCOB");
        $query->execute(array(
            "P_CDTIPCOB" => $cdTipCob,
            "NRORG" => $this->environment->getNrorg()
        ));
        $tipoCobranca = $query->fetchAll();
        return is_array($tipoCobranca) && count($tipoCobranca) ? $tipoCobranca[0]['NMTIPOCOBR'] : "";
    }
    
    public function getCdFilcentCmp($cdfilial) {
        $query = $this->connection->prepare(
            "SELECT NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) AS CDFILCENTCMP, PARASUPRI.CDOPERADOR AS CDOPERADORSEMREST
               FROM PARASUPRI INNER JOIN FILIAL ON PARASUPRI.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                                               AND PARASUPRI.NRORG = FILIAL.NRORG
              WHERE FILIAL.CDFILIAL = :CDFILIAL
                AND PARASUPRI.NRORG = :NRORG");
        $query->execute(array(
            "CDFILIAL" => $cdfilial,
            "NRORG"    => $this->environment->getNrOrg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return $existe[0];
    }
    
    public function getCdComprador($cdfillanc, $cdfildest, $nrautoforn) {
        $query = $this->connection->prepare(
            "SELECT CDOPERADOR 
               FROM AUTOFORNE
              WHERE CDFILLANC  = :CDFILLANC
                AND CDFILDEST  = :CDFILDEST
                AND NRAUTOFORN = :NRAUTOFORN
                AND NRORG      = :NRORG");
        $query->execute(array(
            "CDFILLANC"  => $cdfillanc,
            "CDFILDEST"  => $cdfildest,
            "NRAUTOFORN" => $nrautoforn,
            "NRORG"    => $this->environment->getNrOrg()
        ));
        $existe = $query->fetchAll();
        if(sizeof($existe) > 0)
            return $existe[0]['CDOPERADOR'];
    }
    
    public function retornaDadosEmailFornecedor($cdforneced) 
    {
        $query = "SELECT F.IDTPIJURFORN,
                         F.NRINSJURFORN,
                         F.CDFORNECED,
                         F.NMFANTFORN,
                         F.IDUTILZIPAF,
                         NVL(F.IDTPENVAFNORMAL, 'E') AS IDTPENVAFNORMAL,
                         F.IDTPENVAFFOR,
                         F.CDFORNERELACAF AS CDFORNERELAC,
                         NVL((SELECT DSEMAILFORN FROM TABLE(DADOS_FORN_EMAIL (E.CDFORNECED, 'S', '', E.NRORG))), E.DSEMAILCOT) AS DSEMAILCOT,
                         E.DSMAILCOTCOP 
                    FROM FORNECEDOR F INNER JOIN FORNECEDOR E ON NVL(F.CDFORNERELACAF, F.CDFORNECED) = E.CDFORNECED
                                                             AND F.NRORG = E.NRORG
                   WHERE F.CDFORNECED = :P_CDFORNECED
                     AND F.NRORG = :NRORG";
                      
        $params = [
            "P_CDFORNECED" => $cdforneced,
            "NRORG"        => $this->environment->getNrOrg()
        ];
        
        $dataSet = self::executaSql($query, $params);
        
        return is_array($dataSet) && count($dataSet) ? $dataSet[0] : false;
    }
    
    public function retornaLinkEcommerce($row)
    {   
        $query = "SELECT MAX(DSLINKECOMMERCE) AS DSLINKECOMMERCE
                    FROM PARAMGERALECOMMERCE 
                   WHERE INSTR(:P_CDFILCENTCMP, CDFILIAL) > 0
                     AND NRORG = :NRORG";

        $params = array(
            "P_CDFILCENTCMP" => $row['CDFILCENTCMP'],
            "NRORG"        => $this->environment->getNrOrg()
        );
        
        $dataSet = self::executaSql($query, $params);
        
        return is_array($dataSet) && count($dataSet) ? $dataSet[0] : '';
    }
    
    public function retornaEmailFornecedor($cdforneced) {
        $query = $this->connection->prepare(
            "SELECT LISTAGG(CASE INSTR(REPLACE(DSEMAILECO, ',', ';'), ',', -1, 1) WHEN LENGTH(REPLACE(DSEMAILECO, ',', ';')) THEN SUBSTR(REPLACE(DSEMAILECO, ',', ';'), 1, INSTR(REPLACE(DSEMAILECO, ',', ';'), ',', -1, 1) -1) ELSE REPLACE(DSEMAILECO, ',', ';') END, ';') WITHIN GROUP (ORDER BY DSEMAILECO) AS DSLOGINECO FROM ( SELECT REPLACE(F.DSEMAILCOT, ',', ';') AS DSEMAILECO FROM FORNECEDOR F WHERE F.CDFORNECED = :CDFORNECED AND F.NRORG = :NRORG UNION SELECT DSEMAILECO FROM DADOSFORNECOMMERCE WHERE CDFORNECED = :CDFORNECED AND NRORG = :NRORG AND IDACESSOAF  = 'S')");
        
        $query->execute(array(
            "CDFORNECED" => $cdforneced,
            "NRORG"    => $this->environment->getNrOrg()
        ));
        
        $emails = $query->fetchAll();
        
        return $emails;
    }
    
    public function retornaLogoEmail()
    {
         $query = $this->connection->prepare(
            "SELECT URLLOGO 
                    FROM APPCONFIG 
                   WHERE IDAPLICATIVO = :P_IDAPLICATIVO AND 
                         NRORG = :P_NRORG");
        
        $query->execute(array(
            "P_IDAPLICATIVO" => 'PORTAL E-COMMERCE',
            "P_NRORG"        => $this->environment->getNrorgTrab()
        ));
        
        $emails = $query->fetchAll();
        
        return $emails;
    }

    public function findDataLancamento($row)
    {
        $query = "SELECT SYSDATE AS DTLANC
                        FROM PARAMGERAL
                    WHERE IDUTILDTPROC = 'N'
                    UNION
                    SELECT NVL(MAX(PARAMFILIAL.DTPROCESSA), SYSDATE) 
                        FROM PARAMGERAL, PARAMFILIAL
                    WHERE IDUTILDTPROC = 'S' 
                        AND PARAMFILIAL.CDFILIAL = :P_CDFILIAL";
        
        $std = $this->connection->prepare($query);
        
        $std->execute(array(
            "P_CDFILIAL" => $row['CDFILDEST'],
        ));
        
        return $std->fetch();
    }
    
    /**
     * [INÍCIO] ANEXO
     */
     
    /**
     * Salvar localmente.
     */
    public function salvaAnexoLocal($row)
    {
        try {
            $id = uniqid($row['ANEXO'][0]["name"]);
            
            $row['NMPATHANEXO'] = $this->getFilePath($id);
          
            file_put_contents($row['NMPATHANEXO'], $row['ANEXO'][0]["b64File"]);
            
            return $id;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function deletaAnexoLocal($rows)
    {
        try {
            foreach ($rows as $row) {
                $path = $this->getFilePath($row['NRANEXOLANCAF']);
                
                if (file_exists($path)) {
                    unlink($path);
                }
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Salvar file server
     */
    
    public function salvaAnexoInFileServer($anexos, $cdfilial, $nrautoforn)
    {
        try {
            $connection = $this->connection;
            $connection->beginTransaction();
            
            foreach ($anexos as $anexo) {
                $anexo['NMPATHANEXO'] = $this->getFilePath($anexo['NRANEXOLANCAF']);
                
                if (file_exists($anexo['NMPATHANEXO'])) {
                    $arquivo = array();
                    
                    $arquivo["b64File"] = file_get_contents($anexo['NMPATHANEXO']);
                    $arquivo["lastModified"] =  $anexo["ANEXO"][0]["lastModified"];
                    $arquivo["lastModifiedDate"] = $anexo["ANEXO"][0]["lastModifiedDate"];
                    $arquivo["webkitRelativePath"] = $anexo["ANEXO"][0]["webkitRelativePath"];
                    $arquivo["type"] = $anexo["ANEXO"][0]["type"];
                    $arquivo["size"] = $anexo["ANEXO"][0]["size"];
                    $arquivo["name"] = $anexo["ANEXO"][0]["name"];
                    
                    $localPath = $anexo['NMPATHANEXO'];
                    $anexo['NMPATHANEXO'] = $this->saveXmlInFileUplouder($arquivo);
                    
                    unlink($localPath);
                    
                    $anexo['CDFILIAL'] = $cdfilial;
                    $anexo['NRAUTOFORN'] = $nrautoforn;
                    
                    $params = array(
                        'NRANEXOLANCAF'  => $this->newCode->getCodeByTableName('ANEXOLANCAF', $this->environment->getNrOrg()),
                        'CDTELA'         => 'CMP03900',
                        'DTANEXOLANCAF'  => $anexo['DTANEXOLANCAF'],
                        'NMANEXOLANCAF'  => $anexo['ANEXO'][0]["name"],
                        'NMPATHANEXO'    => $anexo['NMPATHANEXO'],
                        'DSANEXOLANCAF'  => isset($anexo['DSANEXOLANCAF']) ? $anexo['DSANEXOLANCAF'] : null,
                        'DSINFOANEXO'    => $this->getFileInfo($anexo),
                        'NRAUTOFORN'     => $nrautoforn,
                        'CDFILDEST'      => $cdfilial,
                        'NRORG'          => $this->environment->getNrOrg(),
                        'NRORGINCLUSAO'  => $this->environment->getNrOrg(),
                        'CDOPERINCLUSAO' => $this->environment->getCdOperador(),
                        'NRORGULTATU'    => $this->environment->getNrOrg(),
                        'CDOPERULTATU'   => $this->environment->getCdOperador(),
                    );
                    
                    $sql = "INSERT INTO ANEXOLANCAF 
                        (
                            NRANEXOLANCAF,
                            CDTELA,
                            DTANEXOLANCAF,
                            NMANEXOLANCAF,
                            NMPATHANEXO,
                            DSANEXOLANCAF,
                            DSINFOANEXO,
                            NRAUTOFORN,
                            CDFILDEST,
                            NRORG,
                            DTINCLUSAO,
                            NRORGINCLUSAO,
                            CDOPERINCLUSAO,
                            DTULTATU,
                            NRORGULTATU,
                            CDOPERULTATU
                        ) VALUES (
                            :NRANEXOLANCAF,
                            :CDTELA,
                            :DTANEXOLANCAF,
                            :NMANEXOLANCAF,
                            :NMPATHANEXO,
                            :DSANEXOLANCAF,
                            :DSINFOANEXO,
                            :NRAUTOFORN,
                            :CDFILDEST,
                            :NRORG,
                            SYSDATE,
                            :NRORGINCLUSAO,
                            :CDOPERINCLUSAO,
                            SYSDATE,
                            :NRORGULTATU,
                            :CDOPERULTATU
                        )";
                    
                    $std = $connection->prepare($sql);
                    $std->execute($params);
                } /*else {
                    DELETAR ARQUIVO CASO ELE NAO EXISTA ?
                }*/
            }
            
            $connection->commit();
            
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }
    
    public function saveXmlInFileUplouder($arquivo)
    {
        if (isset($arquivo)) {
            
            $file = array(
                "name" => time().'.'.explode('/', $arquivo["type"])[1], 
                "lastModified" => $arquivo["lastModified"],
                "lastModifiedDate" => $arquivo["lastModifiedDate"],
                "webkitRelativePath" => $arquivo["webkitRelativePath"],
                "type" => $arquivo["type"],
                "size"  => $arquivo["size"], 
                "b64File" => $arquivo["b64File"]);
                
            $row['ANEXOLANCAF']    = array();
            $row['ANEXOLANCAF'][0] = $file;
            
            $this->fileUploader->uploadFilesInRow($row, 'ANEXOLANCAF', 'ANEXOLANCAF');
            
            return $row['ANEXOLANCAF'][0]['path'];
            
            /*
            
            $row = [
                'FILE' => [
                    [
                        "name" => time().'.'.explode('/', $arquivo["type"])[1], 
                        "type" => $arquivo["type"], 
                        "size" => $arquivo["size"], 
                        "path" => '', 
                        "b64File" => $arquivo["b64File"]
                    ]
                ],
                'FOLDER' => 'ANEXOLANCAF'
            ];
            
            return $this->fileUploader->uploadFile($row)[0]->getRows()[0]['FILE'][0]['PATH'];
            */
            
        } else {
            return false;
        }
    }
    
    /**
     * Visualização da AF
     */
    
    public function salvaAnexoGrid($row)
    {
        try {
            $connection = $this->connection;
            $connection->beginTransaction();
            
            $row['NMPATHANEXO'] = $this->saveXmlInFileUplouder($row['ANEXO'][0]);
            
            $params = array(
                'NRANEXOLANCAF'  => $this->newCode->getCodeByTableName('ANEXOLANCAF', $this->environment->getNrOrg()),
                'NRAUTOFORN'     => $row['NRAUTOFORN'],
                'CDFILDEST'      => $row['CDFILDEST'],
                'CDTELA'         => 'CMP03900',
                'DTANEXOLANCAF'  => $row['DTANEXOLANCAF'],
                'NMANEXOLANCAF'  => $row['ANEXO'][0]["name"],
                'NMPATHANEXO'    => $row['NMPATHANEXO'],
                'DSANEXOLANCAF'  => isset($row['DSANEXOLANCAF']) ? $row['DSANEXOLANCAF'] : null,
                'DSINFOANEXO'    => $this->getFileInfo($row),
                'NRORG'          => $this->environment->getNrOrg(),
                'NRORGINCLUSAO'  => $this->environment->getNrOrg(),
                'CDOPERINCLUSAO' => $this->environment->getCdOperador(),
                'NRORGULTATU'    => $this->environment->getNrOrg(),
                'CDOPERULTATU'   => $this->environment->getCdOperador(),
            );
            
            $sql = "INSERT INTO ANEXOLANCAF 
                (
                    NRANEXOLANCAF,
                    CDTELA,
                    DTANEXOLANCAF,
                    NMANEXOLANCAF,
                    NMPATHANEXO,
                    DSANEXOLANCAF,
                    DSINFOANEXO,
                    NRAUTOFORN,
                    CDFILDEST,
                    NRORG,
                    DTINCLUSAO,
                    NRORGINCLUSAO,
                    CDOPERINCLUSAO,
                    DTULTATU,
                    NRORGULTATU,
                    CDOPERULTATU
                ) VALUES (
                    :NRANEXOLANCAF,
                    :CDTELA,
                    :DTANEXOLANCAF,
                    :NMANEXOLANCAF,
                    :NMPATHANEXO,
                    :DSANEXOLANCAF,
                    :DSINFOANEXO,
                    :NRAUTOFORN,
                    :CDFILDEST,
                    :NRORG,
                    SYSDATE,
                    :NRORGINCLUSAO,
                    :CDOPERINCLUSAO,
                    SYSDATE,
                    :NRORGULTATU,
                    :CDOPERULTATU
                )";
            
            $std = $connection->prepare($sql);
            $std->execute($params);
            
            $connection->commit();
            
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }
    
    public function deleteAnexoGrid($rows)
    {
        try {
            $connection = $this->connection;
            $connection->beginTransaction();
            
            foreach ($rows as $row) {
                $this->fileUploader->deleteFile($row['NMPATHANEXO']);
                
                $params = array(
                    'NRANEXOLANCAF' => $row['NRANEXOLANCAF'],
                    'CDTELA'        => $row['CDTELA']
                );
                
                $sql = "DELETE FROM ANEXOLANCAF 
                    WHERE    
                        NRANEXOLANCAF = :NRANEXOLANCAF
                        AND CDTELA = :CDTELA";
                
                $std = $connection->prepare($sql);
                $std->execute($params);
            }
            
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    /**
     * Utilities
     */
    
    private function getFilePath($id)
    {
        /**
         * Salva o arquivo sempre como txt independente do seu formato.
         * 
         * Fonte: http://code.zeedhi.com/teknisa/finbackend/blob/master/src/Teknisa/FIN/Modules/ContaReceber/Services/TitulosAReceberService.php#L4387
         */
        return sys_get_temp_dir() . DIRECTORY_SEPARATOR . 'CMP03900' . $id .'.txt';
    }
    
    private function getFileInfo($row)
    {
        return $row['ANEXO'][0]["lastModified"] . '_' . $row['ANEXO'][0]["lastModifiedDate"] . '_' . 
                $row['ANEXO'][0]["webkitRelativePath"]. '_' . $row['ANEXO'][0]["type"] . '_' . 
                $row['ANEXO'][0]["size"] . '_' . $row['ANEXO'][0]["name"];
    }
    
    public function getFileServerUrl(){
      return $this->_fileServerUrl;
    }
    /**
     * [FIM] ANEXO
     */
    public function findAprovacaoRecusada($row)
    {
        $query = "SELECT
                        APROVALCADA.NRDEMANDA AS NRAUTOFORN,
                        APROVALCADA.DTAPROVACAO,
                        APROVALCADA.DTINCLUSAO,
                        APROVALCADA.IDAPROVADO
                    FROM
                        APROVALCADA
                    WHERE
                        APROVALCADA.CDFILDEST = :P_CDFILDEST
                        AND APROVALCADA.CDFILLANC = :P_CDFILLANC
                        AND APROVALCADA.NRDEMANDA = :P_NRAUTOFORN
                        AND APROVALCADA.NRORG = :P_NRORG
                        AND ROWNUM = 1
                    ORDER BY APROVALCADA.DTAPROVACAO DESC";
        
        $std = $this->connection->prepare($query);
        
        $std->execute(array(
            "P_CDFILDEST" => $row['CDFILDEST'],
            "P_CDFILLANC" => $row['CDFILLANC'],
            "P_NRAUTOFORN" => $row['NRAUTOFORN'],
            "P_NRORG" => $this->environment->getNrOrg(),
        ));
        
        return $std->fetch();
    }
    
    public function getIdsisdos()
    {
        $select = "SELECT IDSISDOS FROM PARAMGERAL WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($select);
        
        $std->execute(array(
            "NRORG" => $this->environment->getNrOrg(),
        ));
        
        $result = $std->fetchAll();
        
        return count($result) ? $result[0]['IDSISDOS'] : false;
    }
    
    public function unidadeDestinoPossuiAlcada($params)
    {
        $query = "SELECT C.NRCONFIGALCADA AS NRCONFIGALCADA
                    FROM CONFIGALCADA C,
                         FILIALCADA F
                      WHERE C.NRCONFIGALCADA = F.NRCONFIGALCADA
                      AND F.CDFILIAL = :P_CDFILDEST";
        
        $std = $this->connection->prepare($query);
        
        $std->execute(array(
            "P_CDFILDEST" => $params['CDFILDEST'],
        ));
        
        $result = $std->fetchAll();
        
        return count($result) ? true : false;
    }
    
    public function utilizaWorkflowController($row)
    {
        $query = "SELECT IDUTLWORKFLOW FROM PARASUPRI WHERE CDFILIAL = (SELECT NVL(CDFILCENTCMP, CDFILIAL) CDFILCENTCMP FROM FILIAL WHERE CDFILIAL = :P_CDFILIAL)";
        $params = array(
            "P_CDFILIAL" => $row['CDFILDEST']
        );
        
        $stmt = $this->connection->prepare($query);
        $stmt->execute($params);
        
        return $stmt->fetchAll();
    }
    
    public function findAdjustments($row)
    {
        $query = "SELECT * 
                    FROM ( SELECT PO.CDARVPROD, PO.CDPRODUTO, PA.CDFILIAL,
                                  PA.VRPERCENTACRESCIMO, PA.VRPERCENTDESCONTO
                             FROM PERCENTAJUSTEITEMAF PA INNER JOIN PRODUTO PO 
                                        ON PA.CDPRODUTO = PO.CDPRODUTO
                                       AND PA.NRORG = PO.NRORG
                            WHERE PA.CDFILIAL = :P_CDFILIAL
                              AND :P_CDARVPROD LIKE PO.CDARVPROD||'%'
                              AND PA.NRORG = :NRORG
                            ORDER BY PO.CDARVPROD DESC )
                   WHERE ROWNUM = 1";
        
        $std = $this->connection->prepare($query);
        
        $std->execute(array(
            "P_CDFILIAL"    => $row['CDFILDEST'],
            "P_CDARVPROD"   => $row['CDARVPROD'],
            "NRORG"         => $this->environment->getNrOrg(),
        ));
        
        return $std->fetch();
    }
    
    public function getCurrentEmail()
    {
        return $this->environment->getCurrentEmail();
    }
    
    public function saveImportProducts($products)
    {
        foreach($products as $row) {
            if($this->updItemAutf($row) === 0) {
                $this->insertItemAutf($row);       
                $this->updateItemsoli($row);
            }
        }
    }
    
    private function updateItemsoli($row)
    {
        $query = "UPDATE ITEMSOLI
                     SET IDPRODIMPAF = 'S'
                   WHERE CDFILLAN   = :P_CDFILLAN
                     AND CDFILSOLI  = :P_CDFILSOLI
                     AND NRSOLICMP  = :P_NRSOLICMP
                     AND CDPRODUTO  = :P_CDPRODUTO
                     AND DTPROGENTR = :P_DTPROGENTR
                     AND NRORG      = :NRORG";
        $params = array(
            "P_CDFILLAN"   => $row['CDFILLANC'],
            "P_CDFILSOLI"  => $row['CDFILDEST'],
            "P_NRSOLICMP"  => $row['NRSOLICMP'],
            "P_CDPRODUTO"  => $row['CDPRODUTO'],
            "P_DTPROGENTR" => $row['DTPROGENTR'],
            "NRORG"        => $this->environment->getNrOrg()
        );
        $result = $this->connection->executeUpdate($query, $params);
        return $result;
    }
    
    private function updItemAutf($row)
    {
        $query = "UPDATE ITEMAUTF
                     SET QTPROGENTAF = QTPROGENTAF + :QTPROGENTAF
              WHERE NRAUTOFORN  = :P_NRAUTOFORN
                AND CDFILDEST   = :P_CDFILDEST
                AND CDFILLANC   = :P_CDFILLANC
                AND CDPRODUTO   = :P_CDPRODUTO
                AND CDMARCA     = :P_CDMARCA
                AND DTPROGENTAF = :P_DTPROGENTR
                AND NRORG       = :NRORG";
        $params = array(
            "QTPROGENTAF"   => $row['QTPROGENTAF'],
            "P_CDFILDEST"   => $row['CDFILDEST'],
            "P_CDFILLANC"   => $row['CDFILLANC'],
            "P_NRAUTOFORN"  => $row['NRAUTOFORN'],
            "P_CDMARCA"     => $row['CDMARCA'],
            "P_CDPRODUTO"   => $row['CDPRODUTO'],
            "P_DTPROGENTR"  => $row['DTPROGENTR'],
            "NRORG"       => $this->environment->getNrOrg()
        );
        $result = $this->connection->executeUpdate($query, $params);
        return $result;
    }
    
    private function insertItemAutf($row)
    {
        $query = "INSERT INTO ITEMAUTF(CDFILDEST, CDFILLANC, NRAUTOFORN, CDMARCA, CDPRODUTO, DTPROGENTAF, QTPROGENTAF, 
                                        VRPREUNIAF, QTVOLUITEMAF, VRINDICEITMAF, VRPERDESAF, VRDESCITMAF, CDFORNECED, 
                                        CDEMPRESA, IDBAIXITAFS, IDBAIXITMAF, IDBAIXITMFUTURA, NRORG) 
                    VALUES (:CDFILDEST, :CDFILLANC, :NRAUTOFORN, :CDMARCA, :CDPRODUTO, :DTPROGENTAF, :QTPROGENTAF, 
                                        :VRPREUNIAF, :QTVOLUITEMAF, :VRINDICEITMAF, :VRPERDESAF, :VRDESCITMAF, :CDFORNECED, 
                                        :CDEMPRESA, :IDBAIXITAFS, :IDBAIXITMAF, :IDBAIXITMFUTURA, :NRORG)";
        
        $params = array(
    		"CDFILDEST"         => $row['CDFILSOLI'],
    		"CDFILLANC"         => $row['CDFILLAN'],
    		"NRAUTOFORN"        => $row['NRAUTOFORN'],
    		"CDMARCA"           => $row['CDMARCA'],
    		"CDPRODUTO"         => $row['CDPRODUTO'],
    		"DTPROGENTAF"       => $row['DTPROGENTR'],
    		"QTPROGENTAF"       => $row['QTPROGENTAF'],
    		"VRPREUNIAF"        => $row['VRPREUNIAF'],
    		"QTVOLUITEMAF"      => $row["QTVOLUITEMAF"],
            "VRINDICEITMAF"     => $row["VRINDICEITMAF"],
            "VRPERDESAF"        => $row["VRPERDESAF"],
            "VRDESCITMAF"       => $row["VRDESCITMAF"],
            "CDFORNECED"        => $row["CDFORNECED"],
            "CDEMPRESA"         => $row["CDEMPRESA"],
            "IDBAIXITAFS"       => $row["IDBAIXITAFS"],
            "IDBAIXITMAF"       => $row["IDBAIXITMAF"],
            "IDBAIXITMFUTURA"   => $row["IDBAIXITMFUTURA"],
    		"NRORG"             => $this->environment->getNrorg()
    	);
        
        $result = $this->connection->executeUpdate($query, $params);
        return $result;
    }
    
    private function executaSql($sql, $params, $consulta = true) {
        try{
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            if($consulta == true) {
                return $std->fetchAll();
            }
            
            return true;
        } catch (\Exception $e){
            throw $e;
        } 
    }
    
    public function insMovOpAFAberto($row) 
    {
        $query =    "INSERT INTO MOVOPAF 
                        (CDFILDESMOV, CDFILLANMOV, NRAUTOMOV, CDPRODMOV, CDMARCMOV,
                         DTPROGENTMOV, DTOPERAF, CDOPERADOR, DSALTERAF, DSJUSTOPERMOV,
                         IDOPERAMOVAF, NRORG)
                    SELECT
                        CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, CDMARCA,
                        DTPROGENTAF, SYSDATE, :P_CDOPERADOR, :P_DESCALTERAF1, :P_DSJUSTOPER, 
                        'A', NRORG
                    FROM
                        ITEMAUTF
                    WHERE
                        CDFILDEST = :P_CDFILDEST   AND
                        CDFILLANC = :P_CDFILLANC   AND
                        NRAUTOFORN = :P_NRAUTOFORN AND
                        NRORG      = :NRORG         AND
                        NOT EXISTS (SELECT
                                        CDFILIAL
                                    FROM
                                        NFRELACAF
                                    WHERE
                                        NFRELACAF.CDFILDEST   = ITEMAUTF.CDFILDEST   AND
                                        NFRELACAF.CDFILLANC   = ITEMAUTF.CDFILLANC   AND
                                        NFRELACAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN  AND
                                        NFRELACAF.CDMARCA     = ITEMAUTF.CDMARCA     AND
                                        NFRELACAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO   AND
                                        NFRELACAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF AND
                                        NFRELACAF.NRORG       = ITEMAUTF.NRORG)";
        $params = array(
    		"P_CDFILDEST"    => $row['CDFILDEST'],
    		"P_CDFILLANC"    => $row['CDFILLANC'],
    		"P_NRAUTOFORN"   => $row['NRAUTOFORN'],
    		"P_DESCALTERAF1" => $row['MESSAGES'][1],
    		"P_DSJUSTOPER"   => $row['MESSAGES'][0],
            "P_CDOPERADOR"   => $this->environment->getCdOperador(),
    		"NRORG"          => $this->environment->getNrorg()
    	);
        
        return self::executaSql($query, $params, false);
    }
    
    public function insMovOpAFPar($row) 
    {
        $query =    "INSERT INTO MOVOPAF
                        (CDFILDESMOV, CDFILLANMOV, NRAUTOMOV, CDPRODMOV, CDMARCMOV, 
                        DTPROGENTMOV, DTOPERAF, CDOPERADOR, DSALTERAF, DSJUSTOPERMOV, 
                        IDOPERAMOVAF, NRORG)   
                    SELECT
                        CDFILDEST  , CDFILLANC, NRAUTOFORN, CDPRODUTO, CDMARCA,
                        DTPROGENTAF, SYSDATE, :P_CDOPERADOR, :P_DESCALTERAF2, :P_DSJUSTOPER, 
                        'A', NRORG
                    FROM
                        ITEMAUTF
                    WHERE
                        CDFILDEST  = :P_CDFILDEST AND
                        CDFILLANC  = :P_CDFILLANC AND
                        NRAUTOFORN = :P_NRAUTOFORN AND
                        NRORG      = :NRORG         AND
                        QTPROGENTAF > QTEFETENTRAF AND
                        EXISTS (SELECT
                                    CDFILIAL
                                FROM
                                    NFRELACAF
                                WHERE
                                    NFRELACAF.CDFILDEST   = ITEMAUTF.CDFILDEST  AND
                                    NFRELACAF.CDFILLANC   = ITEMAUTF.CDFILLANC  AND
                                    NFRELACAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN  AND
                                    NFRELACAF.CDMARCA     = ITEMAUTF.CDMARCA    AND
                                    NFRELACAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO  AND
                                    NFRELACAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF AND
                                    NFRELACAF.NRORG       = ITEMAUTF.NRORG)";
        $params = array(
    		"P_CDFILDEST"    => $row['CDFILDEST'],
    		"P_CDFILLANC"    => $row['CDFILLANC'],
    		"P_NRAUTOFORN"   => $row['NRAUTOFORN'],
    		"P_DESCALTERAF2" => $row['MESSAGES'][2],
    		"P_DSJUSTOPER"   => $row['MESSAGES'][0],
            "P_CDOPERADOR"   => $this->environment->getCdOperador(),
    		"NRORG"          => $this->environment->getNrorg()
    	);
        
        return self::executaSql($query, $params, false);
    }
    
    public function updReAfAbertoPar($row) 
    {
        $query =    "UPDATE ITEMAUTF 
                        SET IDBAIXITMAF = '1'
                      WHERE CDFILDEST  = :P_CDFILDEST
                        AND CDFILLANC  = :P_CDFILLANC
                        AND NRAUTOFORN = :P_NRAUTOFORN
                        AND NRORG      = :NRORG
                        AND QTPROGENTAF > NVL(QTEFETENTRAF, 0)
                        AND EXISTS (SELECT CDFILIAL
                                      FROM NFRELACAF
                                     WHERE NFRELACAF.CDFILDEST   = ITEMAUTF.CDFILDEST
                                       AND NFRELACAF.CDFILLANC   = ITEMAUTF.CDFILLANC
                                       AND NFRELACAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN
                                       AND NFRELACAF.CDMARCA     = ITEMAUTF.CDMARCA
                                       AND NFRELACAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO
                                       AND NFRELACAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF
                                       AND NFRELACAF.NRORG       = ITEMAUTF.NRORG)";
        $params = array(
    		"P_CDFILDEST"  => $row['CDFILDEST'],
    		"P_CDFILLANC"  => $row['CDFILLANC'],
    		"P_NRAUTOFORN" => $row['NRAUTOFORN'],
    		"NRORG"        => $this->environment->getNrorg()
    	);
        
        return self::executaSql($query, $params, false);
    }
    
    public function updReAfAberto($row) 
    {
        $query =    "UPDATE ITEMAUTF
                        SET IDBAIXITMAF = NULL
                      WHERE CDFILDEST  = :P_CDFILDEST
                        AND CDFILLANC  = :P_CDFILLANC
                        AND NRAUTOFORN = :P_NRAUTOFORN
                        AND NRORG      = :NRORG
                        AND NOT EXISTS (SELECT CDFILIAL
                                          FROM NFRELACAF
                                         WHERE NFRELACAF.CDFILDEST   = ITEMAUTF.CDFILDEST
                                           AND NFRELACAF.CDFILLANC   = ITEMAUTF.CDFILLANC
                                           AND NFRELACAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN
                                           AND NFRELACAF.CDMARCA     = ITEMAUTF.CDMARCA
                                           AND NFRELACAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO
                                           AND NFRELACAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF
                                           AND NFRELACAF.NRORG       = ITEMAUTF.NRORG)";
        $params = array(
    		"P_CDFILDEST"  => $row['CDFILDEST'],
    		"P_CDFILLANC"  => $row['CDFILLANC'],
    		"P_NRAUTOFORN" => $row['NRAUTOFORN'],
    		"NRORG"        => $this->environment->getNrorg()
    	);
        
        return self::executaSql($query, $params, false);
    }
    
    public function getCountBaixaItm($row) 
    {
        $query =    "SELECT COUNT(DECODE(IDBAIXITMAF, NULL, '¿')) AS NRABERTO,
                            COUNT(DECODE(IDBAIXITMAF, '1', '¿')) AS NRPARCIAL,
                            COUNT(DECODE(IDBAIXITMAF, '2', '¿')) AS NRTOTAL,
                            COUNT(DECODE(IDBAIXITMAF, '3', '¿')) AS NRMANUAL,
                            COUNT(*) AS NRCOUNT
                       FROM ITEMAUTF
                      WHERE CDFILDEST  = :P_CDFILDEST
                        AND CDFILLANC  = :P_CDFILLANC
                        AND NRAUTOFORN = :P_NRAUTOFORN
                        AND NRORG      = :NRORG";
        $params = array(
    		"P_CDFILDEST"  => $row['CDFILDEST'],
    		"P_CDFILLANC"  => $row['CDFILLANC'],
    		"P_NRAUTOFORN" => $row['NRAUTOFORN'],
    		"NRORG"        => $this->environment->getNrorg()
    	);
        
        return self::executaSql($query, $params);
    }
    
    public function updAtuBaixaAF($row, $stBaixaAF) 
    {
        $query = "UPDATE AUTOFORNE
                     SET IDBAIXAAF  = :P_IDBAIXAAF
                   WHERE CDFILDEST  = :P_CDFILDEST
                     AND CDFILLANC  = :P_CDFILLANC
                     AND NRAUTOFORN = :P_NRAUTOFORN
                     AND NRORG      = :NRORG";
        $params = array(
    		"P_IDBAIXAAF"  => $stBaixaAF,
    		"P_CDFILDEST"  => $row['CDFILDEST'],
    		"P_CDFILLANC"  => $row['CDFILLANC'],
    		"P_NRAUTOFORN" => $row['NRAUTOFORN'],
    		"NRORG"        => $this->environment->getNrorg()
    	);
        
        return self::executaSql($query, $params, false);
    }
    
    public function AJUSTE_CONTPREVISTA($row)
    {
        try {
            $connection = $this->connection;
            $procedure  = new StoredProcedure($connection, 'AJUSTE_CONTPREVISTA');
            $procedure->addParam(new Param('P_CDFILDEST',  Param::PARAM_INPUT,  $row['CDFILDEST'],  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILLANC',  Param::PARAM_INPUT,  $row['CDFILLANC'],  Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT,  $row['NRAUTOFORN'], Param::PARAM_TYPE_STR));
            $procedure->execute();
        }
        catch(\Exception $e){
            throw $e;
        }
    }
    
    public function beginTransaction()
    {
        $this->connection->beginTransaction();  
    }
    
    public function commit()
    {
        $this->connection->commit();
    }
    
    public function rollBack()
    {
        $this->connection->rollBack();  
    }
    
    public function getNrorg()
    {
        return $this->environment->getNrOrg();
    }
    
    public function getDiferentItemsAutF($row)
    {
        $query =    "SELECT *
                       FROM ITEMAUTF
                      WHERE CDFILDEST    = :P_CDFILDEST
                        AND CDFILLANC    = :P_CDFILLANC
                        AND NRAUTOFORN   = :P_NRAUTOFORN
                        AND CDPRODUTO||CDMARCA <> :P_CDPRODUTO||:P_CDMARCA
                        AND NRORG        = :NRORG";
        $params = array(
    		"P_CDFILDEST"   => $row['CDFILDEST'],
    		"P_CDFILLANC"   => $row['CDFILLANC'],
    		"P_NRAUTOFORN"  => $row['NRAUTOFORN'],
    		"P_CDPRODUTO"   => $row['CDPRODUTO'],
    		"P_CDMARCA"     => $row['CDMARCA'],
    		"NRORG"         => $this->environment->getNrorg()
    	);
        
        return self::executaSql($query, $params);
    }
    
    public function updateAllItems($row)
    {
        $query = "UPDATE ITEMAUTF
                     SET DTPROGENTAF = :DTPROGENTAF
              WHERE NRAUTOFORN  = :P_NRAUTOFORN
                AND CDFILDEST   = :P_CDFILDEST
                AND CDFILLANC   = :P_CDFILLANC
                AND NRORG       = :NRORG";
        $params = array(
            "P_CDFILDEST"  => $row['CDFILDEST'],
            "P_CDFILLANC"  => $row['CDFILLANC'],
            "P_NRAUTOFORN" => $row['NRAUTOFORN'],
            "DTPROGENTAF"  => $row['DTPROGENTAF'],
            "NRORG"        => $this->environment->getNrOrg()
        );
        $result = $this->connection->executeUpdate($query, $params);
        return $result;
    }
}