<?php
namespace Teknisa\CMP\Modules\Solicitacao\Modules\SolicitacaoCompras\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Exception;
use Doctrine\ORM\EntityManager;

class CMP06900AlteracaoAutomaticaSolicitacaoComprasService {
    protected $connection;
    
    public function __construct(\Doctrine\ORM\EntityManager $entityManager, $environment) {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    public function realizaCommit() {
        $this->entityManager->commit();
    }
    
    public function realizaRollback() {
        $this->entityManager->rollBack();
    }
    
    public function beginTransaction() {
        $this->entityManager->beginTransaction();
    }
    
    /**
     * Reagrupar as funções de acordo com os fluxos:
     * - Utilidades;
     * - Atualização do Grid;
     * - Alteração Automática de Data de Entrega;
     * - Alteração Automática de Produto;
     */
     
    /**
     * Adquire CDGRUPPROD de acordo com a filial passada.
     * 
     * @param array  $params   Parâmetros necessários para executar a query.
     */
    public function getCodigoGrupProd($params) 
    {
        $query = "SELECT CDGRUPPROD FROM PARASUPRI WHERE CDFILIAL = :P_CDFILCENTCMP";
    	
    	try {
        	$std = $this->connection->prepare($query);
        	$std->execute($params);
        	$result = $std->fetchAll();
    	} catch (Exception $e) {
    	    throw $e;
    	}
    	
    	if(is_array($result) && !is_null($result)) {
    	    if (count($result) == 0) {
                return $result;
            }
    	}
    	
    	return $result[0];
    }
    
    /**
     * ########################################################################
     * ############### >>> ATUALIZAÇÃO DE ITENS DO GRID <<< ###################
     * ########################################################################
     */
     
    public function adqFiliOpelogCDFILIOPELOG($params) {
        $query = "SELECT CDFILIOPELOG FROM(SELECT MAX(P.CDFILIOPELOG) CDFILIOPELOG FROM PARAMPRODSUP P WHERE P.CDFILIAL = :P_CDFILIAL AND P.CDPRODUTO = :P_CDPRODUTO) A";
    	
    	try {
        	$std = $this->connection->prepare($query);
        	$std->execute($params);
        	$result = $std->fetchAll();
    	} catch (Exception $e) {
    	    throw $e;
    	}
    	
    	return $result[0]["CDFILIOPELOG"];
    }
    
    /**
     * Adquire um item da tabela ITEMSOLIDEL de acordo com os parâmetros.
     * 
     * Utilizada pelos seguintes procedimentos:
     * * Atualização de itens no Grid;
     * * Atualização Automática de Produtos.
     * 
     * @param array  $params   Parâmetros necessários para executar a query.
     */
    public function adqItemsoliDel($params) {
        $query = "SELECT '1' FROM ITEMSOLIDEL WHERE CDFILSOLI = :P_CDFILSOLI AND CDFILLAN = :P_CDFILLAN AND NRSOLICMP = :P_NRSOLICMP AND CDPRODUTO = :P_CDPRODUTO AND DTPROGENTR = :P_DTPROGENTR";
    	
    	try {
        	$std = $this->connection->prepare($query);
        	$std->execute($params);
        	$result = $std->fetchAll();
    	} catch (Exception $e) {
    	    throw $e;
    	}
    	
    	return $result;
    }
    
    /**
     * Insere um item na tabela ITEMSOLIDEL de acordo com os parâmetros.
     * 
     * Utilizada pelos seguintes procedimentos:
     * * Atualização de itens no Grid;
     * * Atualização Automática de Produtos.
     * 
     * @param array  $params   Parâmetros necessários para executar a query.
     */
    public function acmInsItemSoliDel($params) {
        $query = "INSERT INTO ITEMSOLIDEL(CDFILSOLI, CDFILLAN, NRSOLICMP, CDPRODUTO, DTPROGENTR, QTSOLIORIGDEL) VALUES (:P_CDFILSOLI, :P_CDFILLAN, :P_NRSOLICMP, :P_CDPRODUTO, :P_DTPROGENTR, :P_QTSOLIORIGDEL)";

        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function adqSoliItemPedidoOL($params) {
        $query = "SELECT IDPEDIDOOL FROM ITEMSOLI WHERE CDFILSOLI = :CDFILSOLI AND CDFILLAN = :CDFILLAN AND NRSOLICMP = :NRSOLICMP AND CDPRODUTO = :CDPRODUTO AND DTPROGENTR = :DTPROGENTR";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
    }
    
    public function acmUpdateItemSoli($params) {
        $query = "UPDATE ITEMSOLI SET QTSOLIPROD = NVL(:QTSOLIPROD, QTSOLIPROD), CDFILIOPELOG = :CDFILIOPELOG, QTSOLIORIG = DECODE(QTSOLIORIG, NULL, :QTSOLIORIG, QTSOLIORIG), CDMARCA = :CDMARCA WHERE CDFILSOLI = :CDFILSOLI AND CDFILLAN = :CDFILLAN AND NRSOLICMP = :NRSOLICMP AND CDPRODUTO = :CDPRODUTO AND DTPROGENTR = :DTPROGENTR";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Utilizada pelos seguintes procedimentos:
     * * Atualização Automática de Data de Entrega.
     * * Atualização Automática de Produtos.
     * 
     * @param array  $params   Parâmetros necessários para executar a query.
     */
    public function acmInsMovOpSol($params) {
        $query = "INSERT INTO MOVOPSOL(CDFILSOLMOV, CDFILLANMOV, NRSOLIMOV, CDPRODUTO, DTENTROPER, DTOPERSOL, CDOPERADOR, QTANTOPER, QTDEPOPER, DSJUSTOPER, CDMARCA, CDFILIALOLANT, CDFILIALOLDEP) VALUES (:P_CDFILSOLMOV, :P_CDFILLANMOV, :P_NRSOLIMOV, :P_CDPRODUTO, :P_DTENTROPER, SYSDATE, :P_CDOPERADOR, :P_QTANTOPER, :P_QTDEPOPER, :P_DSJUSTOPER, :P_CDMARCA, :P_CDFILIALOLANT, :P_CDFILIALOLDEP)";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Deleta um item na tabela ITEMSOLIDEL de acordo com os parâmetros.
     * 
     * Utilizada pelos seguintes procedimentos:
     * * Atualização de itens no Grid;
     * * Atualização Automática de Data de Entrega.
     * * Atualização Automática de Produtos.
     * 
     * @param array  $params   Parâmetros necessários para executar a query.
     */
    public function acmDeleteItemSoli($params) {
        $query = "DELETE FROM ITEMSOLI WHERE CDFILSOLI = :P_CDFILSOLI AND CDFILLAN = :P_CDFILLAN AND NRSOLICMP = :P_NRSOLICMP AND CDPRODUTO = :P_CDPRODUTO AND DTPROGENTR = :P_DTPROGENTR";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function adqAutGrSoliIDAUTALTEPRODSOLI() {
        $query = "SELECT AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, MIN(AUTGRUPOPSOLI.PEALTEQTDESOLI) PEALTEQTDESOLI FROM AUTGRUPOPSOLI, OPERGRUPOP, PARASUPRI, FILIAL WHERE AUTGRUPOPSOLI.CDGRUPOPER = OPERGRUPOP.CDGRUPOPER AND AUTGRUPOPSOLI.IDAUTALTEPRODSOLI IS NOT NULL AND NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = PARASUPRI.CDFILIAL AND PARASUPRI.IDBLOQALTSOLAUT = 'S' GROUP BY AUTGRUPOPSOLI.IDAUTALTEPRODSOLI";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute();
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        return $result;
    }
    
    public function adqAutGrSoliIDAUTALTESOLI() {
        $query = "SELECT AUTGRUPOPSOLI.IDAUTALTESOLI, MIN(AUTGRUPOPSOLI.PEALTEQTDESOLI) PEALTEQTDESOLI FROM AUTGRUPOPSOLI, OPERGRUPOP, PARASUPRI, FILIAL WHERE AUTGRUPOPSOLI.CDGRUPOPER = OPERGRUPOP.CDGRUPOPER AND AUTGRUPOPSOLI.IDAUTALTESOLI IS NOT NULL AND NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = PARASUPRI.CDFILIAL AND PARASUPRI.IDBLOQALTSOLAUT = 'S' GROUP BY AUTGRUPOPSOLI.IDAUTALTESOLI";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute();
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        return $result;
    }
    
    public function qryTipoFilial($params) {
        $query = "SELECT CDFILIAL, IDFUNCAOFILI FROM FILIAL WHERE CDFILIAL = :P_CDFILIAL";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        return $result[0];
    }
    
    /**
     * ########################################################################
     * ############## >>> ATUALIZAÇÃO AUTOMÁTICA DE PRODUTO <<< ###############
     * ########################################################################
     */
     
    public function adqArredProduto($params) {
        $query = "SELECT NVL(VRARREDCMP, 0) VRARREDCMP FROM PRODUTO WHERE CDPRODUTO = :P_CDPRODUTO";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
     }
     
    public function adqVerifItemSol($params) {
        $query = "SELECT ITEMSOLI.QTSOLIPROD FROM ITEMSOLI WHERE ITEMSOLI.CDFILSOLI = :P_CDFILSOLI AND ITEMSOLI.CDFILLAN = :P_CDFILLAN AND ITEMSOLI.NRSOLICMP = :P_NRSOLICMP AND ITEMSOLI.CDPRODUTO = :P_CDPRODUTO AND ITEMSOLI.DTPROGENTR = :P_DTPROGENTR";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
     }
     
    public function adqProdFili($params) {
        $query = "SELECT '1' FROM PRODFILI WHERE(CDFILIAL = :P_CDFILIAL) AND (IDPRODATIV = 'I' ) AND (CDPRODUTO = :P_CDPRODUTO)";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
     }
     
    public function adqProdFili1($params) {
        $query = "SELECT '1' FROM PRODFILI WHERE(CDFILIAL = :P_CDFILIAL) AND (NVL(IDUTPRORIGOBRIG, 'N') = 'S') AND (CDPRODUTO = :P_CDPRODUTO)";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
     }
     
    public function acmInsertItemSoli($params) {
        $query = "INSERT INTO ITEMSOLI(CDFILSOLI, CDFILLAN, NRSOLICMP, CDPRODUTO, DTPROGENTR, QTSOLIPROD, DTUTILIZA, IDITMCONS, TXOBSITMSOL, IDBAIXITMSOL, QTTRANSFSOL, NRLOTEESTQ, NRSUBLOTE, CDPRODPROD, CDFILLANCONS, CDFILSOLCONS, NRSOLCMPCONS, CDPRODUTCONS, DTPROGENCONS, CDOPERAPROV, IDSOLIAPROV, DTHRAPROVSOL, IDPRODIMPAF, QTEXCSUGCOMP, QTVOLUITEMSO, IDTPLANITSOL, IDEXPSOLPALM, CDPRODORIG, QTSOLIORIG, CDFILIOPELOG, CDRASTRITM) SELECT CDFILSOLI, CDFILLAN, NRSOLICMP, :PRODNOVO, DTPROGENTR, NVL(:QTSOLIPROD, QTSOLIPROD), DTUTILIZA, IDITMCONS, TXOBSITMSOL, IDBAIXITMSOL, QTTRANSFSOL, NRLOTEESTQ, NRSUBLOTE, CDPRODPROD, CDFILLANCONS, CDFILSOLCONS, NRSOLCMPCONS, CDPRODUTCONS, DTPROGENCONS, CDOPERAPROV, IDSOLIAPROV, DTHRAPROVSOL, IDPRODIMPAF, QTEXCSUGCOMP, NVL(:QTVOLUITEMSO, QTVOLUITEMSO), IDTPLANITSOL, IDEXPSOLPALM, NVL(CDPRODORIG, CDPRODUTO), 0, CDFILIOPELOG, CDRASTRITM FROM ITEMSOLI WHERE CDFILSOLI = :CDFILSOLI AND CDFILLAN = :CDFILLAN AND NRSOLICMP = :NRSOLICMP AND ITEMSOLI.CDPRODUTO = :CDPRODUTO AND DTPROGENTR = :DTPROGENTR";

        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function acmInsertMovopSol($params) {
        $query = "INSERT INTO MOVOPSOL(DTOPERSOL, CDFILSOLMOV, CDFILLANMOV, NRSOLIMOV, CDPRODUTO, DTENTROPER, QTANTOPER, QTDEPOPER, IDOPERAMOVS, CDOPERADOR, DSJUSTOPER) VALUES (:P_DTOPERSOL, :P_CDFILSOLMOV, :P_CDFILLANMOV, :P_NRSOLIMOV, :P_CDPRODUTO, :P_DTENTROPER, :P_QTANTOPER, :P_QTDEPOPER, :P_IDOPERAMOVS, :P_CDOPERADOR, :P_DSJUSTOPER)";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function adqProdesto($params) {
        $query = "SELECT NEWPRODUTO.VRFATOCONV VRFATOCONVNEW, OLDPRODUTO.VRFATOCONV VRFATOCONVOLD FROM PRODUTO OLDPRODUTO, PRODUTO NEWPRODUTO WHERE OLDPRODUTO.CDPRODUTO = :P_OLDPRODUTO AND NEWPRODUTO.CDPRODUTO = :P_NEWPRODUTO AND OLDPRODUTO.CDPRODESTO = NEWPRODUTO.CDPRODESTO";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
     }
     
    public function adqExisteAjuste($params) {
        $query = "SELECT VRPEAJQTDSOL FROM AJUSTEQTDSOL WHERE AJUSTEQTDSOL.CDPRODORIG = :P_CDPRODORIG AND AJUSTEQTDSOL.CDPRODDEST = :P_CDPRODDEST";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
     }
     
    public function acmInsAjuste($params) {
        $query = "INSERT INTO AJUSTEQTDSOL(CDPRODORIG, CDPRODDEST, VRPEAJQTDSOL) VALUES (:P_CDPRODORIG, :P_CDPRODDEST, :P_AJUSTEQTDE)";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function acmUpdateItemSoliAlteracaoAutomatica($params) {
        $query = "UPDATE ITEMSOLI SET QTSOLIPROD = NVL(:QTSOLIPROD, QTSOLIPROD), QTVOLUITEMSO = NVL(:QTVOLUITEMSO, QTVOLUITEMSO), QTSOLIORIG = DECODE(QTSOLIORIG, NULL, :QTSOLIORIG, QTSOLIORIG) WHERE CDFILSOLI = :CDFILSOLI AND CDFILLAN = :CDFILLAN AND NRSOLICMP = :NRSOLICMP AND CDPRODUTO = :CDPRODUTO AND DTPROGENTR = :DTPROGENTR";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function adqAutGrSoli($params) {
        $query = "SELECT AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, MIN(AUTGRUPOPSOLI.PEALTEQTDESOLI) PEALTEQTDESOLI FROM AUTGRUPOPSOLI, OPERGRUPOP, PARASUPRI, FILIAL WHERE AUTGRUPOPSOLI.CDGRUPOPER = OPERGRUPOP.CDGRUPOPER AND AUTGRUPOPSOLI.IDAUTALTEPRODSOLI IS NOT NULL AND OPERGRUPOP.CDOPERADOR = :P_CDOPERADOR AND FILIAL.CDFILIAL = :P_CDFILIAL AND NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = PARASUPRI.CDFILIAL AND PARASUPRI.IDBLOQALTSOLAUT = 'S' GROUP BY AUTGRUPOPSOLI.IDAUTALTEPRODSOLI";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        return $result;
    }
    
    public function qryProduto($params) {
        $query = "SELECT PRODUTO.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, PRODUTO.CDPRODESTO, PRODUTO.VRFATOCONV, PRODUTO.SGUNIDADE, PRODESTO.VRPESOUNID, NVL(PRODUTO.IDPRODATIVPR, 'S') IDPRODATIVPR FROM PRODUTO PRODESTO, PRODUTO WHERE PRODUTO.CDARVPROD = :P_CDARVPROD AND PRODESTO.CDPRODUTO = PRODUTO.CDPRODESTO";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
    }
     
    public function qryVdProduto($params) {
        $query = "SELECT PRODUTO.NMPRODUTO, PRODUTO.VRFATOCONV, PRODUTO.CDPRODUTO, PRODUTO.CDPRODESTO, PRODESTO.VRPESOUNID FROM PRODUTO PRODESTO, PRODUTO WHERE(PRODUTO.CDARVPROD = :P_CDPRODUTO) AND (PRODESTO.CDPRODUTO = PRODUTO.CDPRODESTO)";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
    }
    
    public function adqAjusteQtde($params) {
        $query = "SELECT AJUSTEQTDSOL.CDPRODORIG, AJUSTEQTDSOL.CDPRODDEST, AJUSTEQTDSOL.VRPEAJQTDSOL FROM AJUSTEQTDSOL WHERE AJUSTEQTDSOL.CDPRODORIG = :P_CDPRODUTO";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        return $result;
    }
    
    /**
     * ########################################################################
     * ########## >>> ATUALIZAÇÃO AUTOMÁTICA DE DATA DE ENTREGA <<< ###########
     * ########################################################################
     */
     
    public function adqVerifItemSoli($params) {
        $query = "SELECT 1 FROM ITEMSOLI WHERE CDFILSOLI = :P_CDFILSOLI AND CDFILLAN = :P_CDFILLAN AND NRSOLICMP = :P_NRSOLICMP AND CDPRODUTO = :P_CDPRODUTO AND DTPROGENTR = :P_DTPROGENTR AND NRSEQUCONSOL IS NULL AND NRSOLCMPCONS IS NULL AND IDBAIXITMSOL IS NULL AND NOT EXISTS(SELECT 1 FROM PRODCOMPRA WHERE PRODCOMPRA.CDFILSOLI = ITEMSOLI.CDFILSOLI AND PRODCOMPRA.CDFILLAN = ITEMSOLI.CDFILLAN AND PRODCOMPRA.NRSOLICMP = ITEMSOLI.NRSOLICMP AND PRODCOMPRA.CDPRODUTO = ITEMSOLI.CDPRODUTO AND PRODCOMPRA.DTPROGENTR = ITEMSOLI.DTPROGENTR)";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        return $result;
    }
     
    public function adqItemsoli($params) {
        $query = "SELECT QTSOLIPROD FROM ITEMSOLI WHERE CDFILSOLI = :P_CDFILSOLI AND CDFILLAN = :P_CDFILLAN AND NRSOLICMP = :P_NRSOLICMP AND CDPRODUTO = :P_CDPRODUTO AND DTPROGENTR = :P_DTPROGENTR";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $result = $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
        
        if(is_array($result) && !is_null($result)) {
            if (count($result) == 0) {
                return $result;
            }
        }
        
        return $result[0];
    }
     
    public function acmInsItemSoli($params) {
        $query = "insert into ITEMSOLI(CDFILSOLI, CDFILLAN, NRSOLICMP, CDPRODUTO, DTPROGENTR, DTUTILIZA, QTSOLIPROD, TXOBSITMSOL, IDSOLIAPROV, QTVOLUITEMSO, CDPRODORIG, QTSOLIORIG, CDFILIOPELOG, VRCMPANTERIOR, DTCMPANTERIOR, CDRASTRITM) values (:CDFILSOLI, :CDFILLAN, :NRSOLICMP, :CDPRODUTO, :DTPROGENTR, :DTUTILIZA, :QTSOLIPROD, :TXOBSITMSOL, :IDSOLIAPROV, :QTVOLUITEMSO, :CDPRODORIG, :QTSOLIORIG, :CDFILIOPELOG, :VRCMPANTERIOR, :DTCMPANTERIOR, :CDRASTRITM)";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
     
    public function acmUpdItemSoli($params) {
        $query = "UPDATE ITEMSOLI SET QTSOLIPROD = QTSOLIPROD + :P_QTSOLIPROD WHERE CDFILSOLI = :P_CDFILSOLI AND CDFILLAN = :P_CDFILLAN AND NRSOLICMP = :P_NRSOLICMP AND CDPRODUTO = :P_CDPRODUTO AND DTPROGENTR = :P_DTPROGENTR";
        
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function queryAutGrSoli() {
        $param = array();
        
        $param['P_CDOPERADOR'] = $this->environment->getCdOperador();
        $param['NRORG']        = $this->environment->getNrOrg();
        
        $query = "SELECT NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI) IDAUTALTEPRODSOLI,
                         MIN(AUTGRUPOPSOLI.PEALTEQTDESOLI) PEALTEQTDESOLI,
                         AUTGRUPOPSOLI.NRORG
                    FROM AUTGRUPOPSOLI INNER JOIN OPERGRUPOP ON AUTGRUPOPSOLI.CDGRUPOPER = OPERGRUPOP.CDGRUPOPER
                                                            AND AUTGRUPOPSOLI.NRORG = OPERGRUPOP.NRORG
                   WHERE NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI) IS NOT NULL
                     AND OPERGRUPOP.CDOPERADOR = :P_CDOPERADOR
                     AND OPERGRUPOP.NRORG = AUTGRUPOPSOLI.NRORG
                     AND AUTGRUPOPSOLI.NRORG = :NRORG
                   GROUP BY NVL(AUTGRUPOPSOLI.IDAUTALTEPRODSOLI, AUTGRUPOPSOLI.IDAUTALTESOLI), AUTGRUPOPSOLI.NRORG";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            return $std->fetchAll();
        } catch (Exception $e){
            throw $e;
        }
    }
}