<?php
namespace Teknisa\CMP\Modules\V1\Controllers; 

use Compras\Logic\NecessidadeCompras\NecessidadeCompras;
use Compras\Logic\NecessidadeCompras\PeriodicidadeNaoCalculada;
use Compras\Logic\SolicitacaoCompras\SolicitacaoCompras;
use Planejamento\Logic\PrevisaoConsumo\PrevisaoConsumo;
use Teknisa\CMP\Modules\V1\Services\NecessidadeCompra;
use Teknisa\GER\Modules\V1\Services\NovoCodigo;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;

class TrabnececompProduto extends \Teknisa\GER\Modules\V1\Controllers\TeknisaCrud {

    protected $dataSourceName = "trabnececomp_produto";
    protected $necessidadeCompra;
    protected $procNecessidadeCompras;
    protected $solicitacaoCompras;
    protected $novoCodigo;

    const REMOVE_NECESSIDADE_DATA = 'tab_cmp03001_calculo_necessidade_por_data';
    const REMOVE_NECESSIDADE_PRODUTO = 'tab_cmp03001_calculo_necessidade_por_produto';

    public function __construct($dataSource, $environment, $parameterBag, NecessidadeCompra $necessidadeCompra, NovoCodigo $novoCodigo, SolicitacaoCompras $solicitacaoCompras, NecessidadeCompras $procNecessidadeCompras, PrevisaoConsumo $previsaoConsumo, PeriodicidadeNaoCalculada $periodicidadeNaoCalculada) {
        parent::__construct($dataSource,$environment,$parameterBag);
        $this->necessidadeCompra = $necessidadeCompra;
        $this->procNecessidadeCompras = $procNecessidadeCompras;
        $this->novoCodigo = $novoCodigo;
        $this->solicitacaoCompras = $solicitacaoCompras;
        $this->previsaoConsumo = $previsaoConsumo;
        $this->periodicidadeNaoCalculada = $periodicidadeNaoCalculada;
    }

    public function trabnececompProdutoData(Request\Filter $request, Response $response){
        try{
            $dataInicial = '';
            $dataFinal = '';

            $conditions = $request->getFilterCriteria()->getConditions();
            $filterCriteria = new FilterCriteria($this->dataSourceName);

            foreach($conditions as $condition){
                if($condition['columnName'] == 'DTINICIAL'){
                    $dataInicial = $condition['value'];
                } else {
                    if($condition['columnName'] == 'DTFINAL'){
                        $dataFinal = $condition['value'];
                    } else {
                        $filterCriteria->addCondition($condition['columnName'], $condition['operator'], $condition['value']);
                    }
                }
            }

            if($dataInicial && $dataFinal){
                $filterCriteria->setWhereClause("DTENTRNECCMP >= TO_DATE('{$dataInicial}', 'DD/MM/YYYY') AND DTENTRNECCMP <= TO_DATE('{$dataFinal}', 'DD/MM/YYYY')");
            }

            $dataSource = $this->dataSourceManager->findBy($filterCriteria);
            $response->addDataSet(new DataSet('trabnececompProdutoData', $dataSource->getRows()));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function excluiNecessidadeCompra(Request\Row $request, Response $response){
        try {
            $params = $request->getRow();
            $cont = 0;
            if($params['nomeWidget'] == self::REMOVE_NECESSIDADE_DATA){
                foreach($params['rowsNecessidade'] as $rowNecessidade) {
                    $this->necessidadeCompra->removeNecessidadePorData($rowNecessidade['NRNECECOMP'], $rowNecessidade['DTENTRNECCMP'], $rowNecessidade['CDFILNECECMP'], $rowNecessidade['NRORG']);
                    $cont++;
                }
            } else{
                if($params['nomeWidget'] == self::REMOVE_NECESSIDADE_PRODUTO){
                    foreach($params['rowsNecessidade'] as $rowNecessidade) {
                        $this->necessidadeCompra->removeNecessidadePorProduto($rowNecessidade['NRNECECOMP'], $rowNecessidade['CDPRODNECCMP'], $rowNecessidade['CDFILNECECMP'], $rowNecessidade['NRORG']);
                        $cont++;
                    }
                }
            }

            $response->addDataSet(new DataSet ('contador', array($cont)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }

    public function excluiTrabnececomp(Request\Row $request, Response $response){
        try {
            $params = $request->getRow();
            $this->necessidadeCompra->removeTodasNecessidades($params['nrnececomp'], $params['nrorg']);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), 1));
        }
    }

    public function proceCalculaPrevconsFiliais(Request\Row $request){
        $param = $request->getRow();
        $this->previsaoConsumo->executaProcedureCalculoPrevConsumo($param['paramProcedure']['NRORG'], $param['paramProcedure']['CDFILIAL'], $param['paramProcedure']['CDGRUPFILI'], $param['paramProcedure']['DTCALCULO'], $param['paramProcedure']['PEACRESCIMO'], $param['paramProcedure']['CDPRODINI'], $param['paramProcedure']['CDPRODFIN'], $param['paramProcedure']['CDOPERADOR'], $param['paramProcedure']['DTHRCALCNC']);
    }

    public function procePeriodicidadeNaoCalculada(Request\Row $request){
        $param = $request->getRow();
        $this->periodicidadeNaoCalculada->executaProcedurePeriodicidadeNaoCalculada($param['paramProcedure']['NRORG'], $param['paramProcedure']['CDFILIAL'], $param['paramProcedure']['CDGRUPFILI'], $param['paramProcedure']['CDPRODINI'], $param['paramProcedure']['CDPRODFIN']);
    }

    public function proceNecessidadeDeCompras(Request\Row $request, Response $response){
        $param = $request->getRow();
        $nrnececomp = $this->novoCodigo->getCodeByTableName('NECECOMP', $param['paramProcedure']['NRORG']);
        $this->procNecessidadeCompras->executeProcedureNecessidadeCompras($param['paramProcedure']['CDFILIAL'], $param['paramProcedure']['TCDFILIAL'], $param['paramProcedure']['CDGRUPFILI'], $param['paramProcedure']['DTINICIAL'], $param['paramProcedure']['DTFINAL'], $param['paramProcedure']['CDPRODINI'], $param['paramProcedure']['CDPRODFIN'], intval($param['paramProcedure']['PEACRESCIMO']), $param['paramProcedure']['CDOPERADOR'], $param['paramProcedure']['DTHRCALCNC'], $param['paramProcedure']['IDQTDEZERO'], $nrnececomp, $param['paramProcedure']['EXTRA'], $param['paramProcedure']['CDSUBGRUPO'], $param['paramProcedure']['CDGRUPPROD']);
        $response->addDataSet(new DataSet('nrnececomp', array($nrnececomp)));
    }

    public function proceGeraSolicitacao(Request\Row $request){
        try {
            $param = $request->getRow();
            $cdfiliais = explode('_', $param['paramProcedure']['CDFILIAL']);
            foreach ($cdfiliais as $cdfilial) {
                $this->necessidadeCompra->proceGeraSolicitacao($cdfilial, $param['paramProcedure']['NRNECECOMP'], $param['paramProcedure']['CDOPERADOR'], $param['paramProcedure']['EXTRA']);
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }
}