<?php
namespace Teknisa\CMP\Services; 

use \Teknisa\Model\Suprimentos\Entities\Autoforne;
use \Teknisa\Model\Suprimentos\Entities\Itemautf;

class InconsistenciaAFService
{
    
    protected $entityManager;
    protected $connection;
    protected $environment;

    public function __construct($entityManager, $environment)
    {
        $this->entityManager = $entityManager;
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    
    public function executaSql($sql, $params, $consulta = true)
    {
        try{
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            if($consulta == true) {
                return $std->fetchAll();
            }
            
            return true;
        } catch (\Exception $e){
            throw $e;
        } 
    }
    
    
    public function retornaAutoforne($cdfildest, $cdfillanc, $nrautoforn)
    {
        
        $autoforne = $this->entityManager->getRepository('\Teknisa\Model\Suprimentos\Entities\Autoforne')
            ->findOneBy(array(
                'cdfildest' => $cdfildest,
                'cdfillanc' => $cdfillanc,
                'nrautoforn' => $nrautoforn,
                'nrorg' => $this->environment->getNrOrgTrab()
            ));
        
        $autoforne = $autoforne instanceof Autoforne ? $autoforne : false;
        
        return $autoforne;
        
    }
    
    public function retornaListaItemAutfAF($cdfildest, $cdfillanc, $nrautoforn)
    {
        $itemautf = $this->entityManager->getRepository('\Teknisa\Model\Suprimentos\Entities\Itemautf')
            ->findBy(array(
                'cdfildest' => $cdfildest,
                'cdfillanc' => $cdfillanc,
                'nrautoforn' => $nrautoforn,
                'nrorg' => $this->environment->getNrOrgTrab()
            ));
            
        $itemautf = count($itemautf) ? $itemautf : false;
        
        return $itemautf;
    }
    
    
    public function retornaInconsistencias($cdfildest, $cdfillanc, $nrautoforn, $cdfilcent)
    {
        $select = "SELECT CDFILDEST, CDFILLANC, NRAUTOFORN, CDPRODUTO, CDMARCA, TO_CHAR(DTPROGENTAF,'DD/MM/YYYY') DTPROGENTAF, CDFORNECED, CDERRO, '' DSERRO FROM TABLE((INCONSISTENCIA_AF(:CDFILDEST,:CDFILLANC,:NRAUTOFORN,:CDFILCENT,:NRORG))) INCONSISTENCIA";
        
        $params = [
            "CDFILDEST"     => $cdfildest,
            "CDFILLANC"     => $cdfillanc,
            "NRAUTOFORN"    => $nrautoforn,
            "CDFILCENT"     => $cdfilcent,
            "NRORG"         => $this->environment->getNrOrgTrab()
        ];
        
        $inconsistencias = self::executaSql($select, $params);

        return count($inconsistencias) ? $inconsistencias : false;
    }
    
    
    public function atualizaAF($cdfildest, $cdfillanc, $nrautoforn, $errosAF, $afForaLimite, $situacaoAF, $gravaIncons = true)
    {
        if($gravaIncons) {
            $update = "UPDATE AUTOFORNE 
                          SET DSINCONSAF    = :P_DSINCONSAF,
                              IDSITUATUAAF  = :P_IDSITUATUAAF,
                              IDAFFORALIM   = :P_IDAFFORALIM,
                              CDGERENTE     = NULL,
                              IDAFCONS      = 'S'
                        WHERE CDFILDEST  = :P_CDFILDEST 
                          AND CDFILLANC  = :P_CDFILLANC
                          AND NRAUTOFORN = :P_NRAUTOFORN
                          AND NRORG      = :NRORG";
                          
            $params = [
                "P_CDFILDEST"    => $cdfildest,
                "P_CDFILLANC"    => $cdfillanc,
                "P_NRAUTOFORN"   => $nrautoforn,
                "P_DSINCONSAF"   => $errosAF,
                "P_IDSITUATUAAF" => $situacaoAF,
                "P_IDAFFORALIM"  => $afForaLimite,
                "NRORG" => $this->environment->getNrOrg()
            ];
            
        } else {
            $update = "UPDATE AUTOFORNE 
                          SET DSINCONSAF = :P_DSINCONSAF
                        WHERE CDFILDEST  = :P_CDFILDEST 
                          AND CDFILLANC  = :P_CDFILLANC
                          AND NRAUTOFORN = :P_NRAUTOFORN
                          AND NRORG      = :NRORG";
            
            $params = [
                "P_CDFILDEST"   => $cdfildest,
                "P_CDFILLANC"   => $cdfillanc,
                "P_NRAUTOFORN"  => $nrautoforn,
                "P_DSINCONSAF"  => $errosAF,
                "NRORG" => $this->environment->getNrOrg()
            ];
            
        }

        self::executaSql($update, $params, false);
    }
    
    public function clearInconsItemautf($cdfildest, $cdfillanc, $nrautoforn)
    {
        $update = "UPDATE ITEMAUTF
                      SET DSINCONSITAF = NULL
                    WHERE CDFILDEST  = :P_CDFILDEST
                      AND CDFILLANC  = :P_CDFILLANC
                      AND NRAUTOFORN = :P_NRAUTOFORN
                      AND NRORG      = :NRORG";
            
        $params = [
            "P_CDFILDEST"   => $cdfildest,
            "P_CDFILLANC"   => $cdfillanc,
            "P_NRAUTOFORN"  => $nrautoforn,
            "NRORG" => $this->environment->getNrOrg()
        ];

        self::executaSql($update, $params, false);
        
    }
    
    
    public function atualizaItemAF($cdfildest, $cdfillanc, $nrautoforn, $cdmarca, $cdproduto, $errosItemAF)
    {
        $update = "UPDATE ITEMAUTF
                      SET DSINCONSITAF = :P_DSINCONSITAF
                    WHERE CDFILDEST  = :P_CDFILDEST
                      AND CDFILLANC  = :P_CDFILLANC
                      AND NRAUTOFORN = :P_NRAUTOFORN
                      AND CDMARCA    = NVL(:P_CDMARCA, CDMARCA)
                      AND CDPRODUTO  = NVL(:P_CDPRODUTO, CDPRODUTO)
                      AND NRORG      = :NRORG";
            
        $params = [
            "P_DSINCONSITAF"    => $errosItemAF,
            "P_CDFILDEST"       => $cdfildest,
            "P_CDFILLANC"       => $cdfillanc,
            "P_NRAUTOFORN"      => $nrautoforn,
            "P_CDMARCA"         => $cdmarca,
            "P_CDPRODUTO"       => $cdproduto,
            
            "NRORG" => $this->environment->getNrOrg()
        ];

        self::executaSql($update, $params, false);
    }
    
}
   